<?xml version='1.0' encoding='UTF-8'?>
<!-- eBS                                                            -->
<!-- Digital text-critical editions of Slovene literature           -->
<!-- ZRC SAZU, IJS                                                  -->
<!--                                                                -->
<!-- Stylesheet for conversion of TEI eBS to HTML                   -->
<!--                                                                -->
<!-- Toma&zcaron; Erjavec,                                          -->
<!-- 2007-02-10                                                     -->

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl="http://exslt.org/common" exclude-result-prefixes="exsl"
  extension-element-prefixes="exsl" version="1.1">

  <xsl:import href="hdr2html.xsl"/>

  <xsl:param name="VERSION">bs2html.xsl ver. 2006-07-25</xsl:param>

  <xsl:param name="split"/>
  <xsl:param name="debug"/>
  <xsl:param name="verbose"/>

  <xsl:param name="ENCODING">standard</xsl:param>
  <!-- or PUA -->
  <xsl:param name="PFONT">'Doulos SIL',  'Cardo', 'Arial Unicode MS'</xsl:param>
  <xsl:param name="outName">bs</xsl:param>
  <xsl:param name="outDir"/>

  <xsl:param name="ENCSUFFIX">.zrcola</xsl:param>
  <xsl:variable name="ENCSUFF">
    <xsl:if test="$ENCODING = 'PUA'">
      <xsl:value-of select="$ENCSUFFIX"/>
    </xsl:if>
  </xsl:variable>

  <xsl:param name="homeURL" select="concat($outName,'.html')"/>
  <xsl:param name="teiHeader-en" select="concat($outName,'-teiHeader','-en')"/>
  <xsl:param name="teiHeader-sl" select="concat($outName,'-teiHeader','-sl')"/>
  <xsl:variable name="para-suff">-para</xsl:variable>
  <xsl:variable name="figure-prefix">bs.facs.</xsl:variable>

  <xsl:param name="proj-name">Elektronske znanstvenokriti&#x10D;ne izdaje slovenskega slovstva</xsl:param>
  <xsl:param name="proj-url">http://nl.ijs.si/e-zrc/</xsl:param>
  <!--xsl:param name="ZRCOLA">http://zrcola.zrc-sazu.si/</xsl:param-->
  <xsl:param name="ZRCOLA">../index-sl.html#zrcola</xsl:param>
  <xsl:param name="ZRCOLAID">zrcola</xsl:param>

  <xsl:param name="contact">Vprašanja in komentarje pošljite na  </xsl:param>
  
  <xsl:param name="teiHeader-desc-en">ENGLISH TEI HEADER</xsl:param>
  <xsl:param name="teiHeader-desc-sl">Kolofon TEI</xsl:param>
  <xsl:variable name="edition-name">Izdaja</xsl:variable>
  <xsl:variable name="para-name">Vzporedni prikaz</xsl:variable>

  <xsl:variable name="toc-top">Na vrh</xsl:variable>
  <xsl:variable name="toc-brief">Glavno kazalo</xsl:variable>
  <xsl:variable name="toc-full">Raz&#x10D;lenjeno kazalo</xsl:variable>
  <xsl:variable name="toc-div">Kazalo poglavja</xsl:variable>
  <xsl:variable name="nav-prev">Nazaj</xsl:variable>
  <xsl:variable name="nav-next">Naprej</xsl:variable>

  <!--     background-image: url(pdb-notyet.jpg); -->
  <xsl:variable name="css_style"> 
    BODY {color: #000000; background-color: #FFFFCC; font-family: "Times New Roman", "Times"; }
    .normal  {font-family: "Times" }
    A:visited {color: #000077;} 
    P {font-family: <xsl:value-of select="$PFONT"/>} 
    TABLE {font-family: <xsl:value-of select="$PFONT"/>} 
    UL {font-family: <xsl:value-of select="$PFONT"/>} 
    OL {font-family: <xsl:value-of select="$PFONT"/>} 
    DL {font-family: <xsl:value-of select="$PFONT"/> }
    .normal {font-family: Times; } 
    .small {font-size-adjust: .8} <!--IE problem with {font-size: smaller} --> 
    .break {margin-top: 3px; margin-bottom: 3px}
    .center {text-align: center; } 
    .right {text-align: right; } 
    .justify {text-align: justify; }
    .suphead {font-weight: normal; font-size: smaller} 
    .subhead {font-weight: normal; font-size:smaller} 
    .oddsent {background-color: #DFF9F9;} 
    .evensent {background-color: #FFFFBB;} 
    .oddmark {background-color: #ACD7D7;} 
    .evenmark {background-color: #EEDD77;} 
    .ocs {font-family: '01 CERKola', <xsl:value-of select="$PFONT"/>; } 
    span.noteref {font-style: normal} 
    span.strike {text-decoration: line-through} 
    span.sound {font-family: Arial, Verdana; font-size: smaller;}
    span.parnum {font-family: Arial, Verdana; font-size: smaller; color: #696969; padding-right: 1em; } 
    span.meta {font-family: Arial, Verdana; font-size: smaller; color: #696969;} 
    span.exact {color: #696969; } 
    span.lossy {color: #BEBEBE; } 
    span.janus {color: #A52A2A; }
  </xsl:variable>

  <!--xsl:param name="background">img/background.jpg</xsl:param-->

  <xsl:param name="def-title">
    <xsl:value-of select="//teiHeader/fileDesc/titleStmt/title[1]"/>
  </xsl:param>

  <xsl:variable name="html-footer">
    <HR/>
    <SMALL>
      <A HREF="http://validator.w3.org/check?uri=referer">
        <IMG border="0" src="http://www.w3.org/Icons/valid-html401" alt="Valid HTML 4.01!"
          height="31" width="88"/>
      </A>
      <A HREF="http://jigsaw.w3.org/css-validator/">
        <IMG border="0" src="http://www.w3.org/Icons/valid-css" alt="Valid CSS!" height="31"
          width="88"/>
      </A>
      <!--A HREF="http://www.w3.org/WAI/WCAG1AA-Conformance"><IMG border="0" class="conform" 
       src="http://www.w3.org/WAI/wcag1AA" 
       alt="Level Double-A conformance icon, W3C-WAI Web Content Accessibility Guidelines 1.0" 
       height="32" width="88"/></A-->
      <!--Creative Commons License-->
      <a rel="license" href="http://creativecommons.org/licenses/by-nd/2.5/si/">
        <img alt="Creative Commons License" border="0"
          src="http://i.creativecommons.org/l/by-nd/2.5/si/88x31.png"/>
      </a>
      <!-- To delo je licencirano z -->
      <!--
        Avtorske pravice za besedilo te izdaje ureja licenca
        <a rel="license" href="http://creativecommons.org/licenses/by-nd/2.5/si/">Creative Commons Priznanje avtorstva-Brez
        predelav 2.5 Slovenija</a>
        -->
      <!-- 
        <rdf:RDF xmlns="http://web.resource.org/cc/" xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:rdfs="http://www.w3.org/2000/01/rdf-schema#">
        <Work rdf:about="">
        <license rdf:resource="http://creativecommons.org/licenses/by-nd/2.5/si/" />
        </Work>
        <License rdf:about="http://creativecommons.org/licenses/by-nd/2.5/si/"><permits rdf:resource="http://web.resource.org/cc/Reproduction"/><permits rdf:resource="http://web.resource.org/cc/Distribution"/><requires rdf:resource="http://web.resource.org/cc/Notice"/><requires rdf:resource="http://web.resource.org/cc/Attribution"/></License></rdf:RDF>
      -->
      <!--/Creative Commons License-->
      <BR/>
      <SPAN class="meta">
        <xsl:text>Datoteka HTML narejena s pretvorbo iz baze v </xsl:text>
        <A HREF="http://www.tei-c.org.uk/P4X/">TEI P4/XML</A>. </SPAN>
      <BR/>
      <xsl:apply-templates mode="footer" select="//teiHeader//availability/p"/>
      <BR/>
      <xsl:apply-templates mode="footer" select="//teiHeader//projectDesc/p"/>
      <BR/>
        <SPAN class="meta">
          <xsl:value-of select="concat($contact,//teiHeader//principal[1])"/>
        </SPAN>
    </SMALL>
  </xsl:variable>

  <xsl:output method="html" encoding="us-ascii"
    doctype-public="-//W3C//DTD HTML 4.01 Transitional//EN" indent="yes"/>

  <xsl:strip-space elements="div page"/>
  <xsl:preserve-space elements="head p note hi add del corr"/>

  <xsl:template match="/">
    <xsl:call-template name="outputChunk">
      <xsl:with-param name="outFile" select="//teiHeader/@id"/>
      <xsl:with-param name="title">
        <xsl:value-of select="concat($teiHeader-desc-sl,': ')"/>
        <xsl:value-of select="//teiHeader/fileDesc/titleStmt/title[1]"/>
        <xsl:text> (</xsl:text>
        <xsl:value-of select="//teiHeader//@date.updated"/>
        <xsl:text>)</xsl:text>
      </xsl:with-param>
      <xsl:with-param name="content">
        <!--xsl:call-template name="navpanel"/-->
        <xsl:apply-templates select="TEI.2/teiHeader"/>
        <!--xsl:call-template name="navpanel"/-->
      </xsl:with-param>
    </xsl:call-template>
    <xsl:apply-templates select="TEI.2/text"/>
  </xsl:template>

  <xsl:template match="text">
    <xsl:variable name="title">
      <xsl:choose>
        <xsl:when test="//teiHeader">
          <xsl:value-of select="//fileDesc/titleStmt/title[1]"/>
          <xsl:text> (</xsl:text>
          <xsl:value-of select="//teiHeader/@date.updated"/>
          <xsl:text>)</xsl:text>
        </xsl:when>
        <xsl:otherwise>
          <xsl:copy-of select="$def-title"/>
          <xsl:text/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <xsl:variable name="head">
      <xsl:choose>
        <xsl:when test="//teiHeader">
          <H1 align="center">
            <xsl:value-of select="$title"/>
          </H1>
          <xsl:for-each select="//fileDesc/titleStmt/author">
            <H2>
              <xsl:value-of select="."/>
            </H2>
          </xsl:for-each>
          <H2>
            <xsl:value-of select="$edition-name"/>
            <xsl:text> </xsl:text>
            <xsl:value-of select="//editionStmt/edition"/>
          </H2>
          <xsl:for-each select="//fileDesc/titleStmt/respStmt">
            <H3>
              <xsl:value-of select="resp"/>
              <xsl:text> </xsl:text>
              <xsl:value-of select="name"/>
            </H3>
          </xsl:for-each>
        </xsl:when>
        <xsl:otherwise>
          <H1 align="center">
            <xsl:copy-of select="$def-title"/>
          </H1>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <xsl:call-template name="outputChunk">
      <xsl:with-param name="outFile" select="$outName"/>
      <xsl:with-param name="title" select="$title"/>
      <xsl:with-param name="content">
        <xsl:call-template name="navpanel"/>
        <!--xsl:copy-of select="$head"/-->
        <xsl:apply-templates select="front"/>
        <A name="TOC-main"/>
        <xsl:call-template name="toc-main">
          <xsl:with-param name="head" select="$toc-brief"/>
          <xsl:with-param name="level">1</xsl:with-param>
        </xsl:call-template>
        <A name="TOC"/>
        <xsl:call-template name="toc-main">
          <xsl:with-param name="head" select="$toc-full"/>
          <xsl:with-param name="prefix">TOC</xsl:with-param>
          <xsl:with-param name="level">5</xsl:with-param>
        </xsl:call-template>
        <xsl:apply-templates select="body"/>
        <xsl:apply-templates select="back"/>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="body">
    <xsl:apply-templates/>
  </xsl:template>

  <xsl:template match="front">
    <A name="bs"/>
    <xsl:apply-templates/>
    <HR/>
  </xsl:template>

  <xsl:template match="back">
    <HR/>
    <xsl:apply-templates/>
  </xsl:template>

  <!-- OLD
<xsl:template match="divGen" mode="toc">
  <xsl:param name="level">1</xsl:param>
  <xsl:param name="suffix"/>
  <xsl:if test="$level">
    <LI>
      <A>
        <xsl:attribute name="href">
          <xsl:call-template name="href">
            <xsl:with-param name="suffix" select="$suffix"/>
          </xsl:call-template>
        </xsl:attribute>
        <xsl:value-of select="$para-name"/>
      </A>
      <xsl:if test="id(@corresp)/div[@corresp] and $level &gt; 1">
        <UL>
          <xsl:apply-templates  mode="toc" select="id(@corresp)/div[@corresp]">
            <xsl:with-param name="level" select="$level - 1"/>
            <xsl:with-param name="suffix" select="concat($suffix,$para-suff)"/>
          </xsl:apply-templates>
        </UL>
      </xsl:if>
    </LI>
  </xsl:if>
</xsl:template>
-->

  <xsl:template match="div" mode="toc">
    <xsl:param name="level">1</xsl:param>
    <xsl:param name="prefix"/>
    <xsl:param name="suffix"/>
    <xsl:variable name="head">
      <xsl:choose>
        <xsl:when test="head">
          <xsl:apply-templates select="head" mode="toc"/>
          <xsl:if test="docAuthor">
            <xsl:text> (</xsl:text>
            <xsl:apply-templates select="docAuthor" mode="toc"/>
            <xsl:text>)</xsl:text>
          </xsl:if>
        </xsl:when>
        <xsl:otherwise>
          <xsl:if test="$debug">
            <xsl:number level="multiple"/>
            <xsl:text> (ni naslova???)</xsl:text>
          </xsl:if>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <xsl:variable name="href">
      <xsl:call-template name="href">
        <xsl:with-param name="suffix" select="$suffix"/>
      </xsl:call-template>
    </xsl:variable>
    <xsl:if test="$level and (string-length($head) &gt; 0)">
      <!-- don't output if empty head! -->
      <LI>
        <xsl:if test="$prefix">
          <xsl:call-template name="anchor">
            <xsl:with-param name="suffix">
              <xsl:text>.</xsl:text>
              <xsl:value-of select="$prefix"/>
            </xsl:with-param>
          </xsl:call-template>
        </xsl:if>
        <xsl:choose>
          <xsl:when test="@type='dead part' and $split">
            <B>
              <xsl:value-of select="$head"/>
            </B>
          </xsl:when>
          <xsl:otherwise>
            <A href="{$href}">
              <xsl:value-of select="$head"/>
            </A>
          </xsl:otherwise>
        </xsl:choose>
        <xsl:if test="(div | divGen) and $level &gt; 1">
          <UL>
            <xsl:apply-templates mode="toc" select="div | divGen">
              <xsl:with-param name="level" select="$level - 1"/>
              <xsl:with-param name="prefix" select="$prefix"/>
              <xsl:with-param name="suffix" select="$suffix"/>
            </xsl:apply-templates>
          </UL>
        </xsl:if>
      </LI>
    </xsl:if>
  </xsl:template>

  <xsl:template match="div">
    <xsl:call-template name="anchor"/>
    <xsl:apply-templates/>
  </xsl:template>

  <xsl:template match="div[@type='section']">
    <xsl:call-template name="anchor"/>
    <!--xsl:if test="preceding-sibling::div"-->
    <xsl:call-template name="navpanel"/>
    <!--/xsl:if-->
    <xsl:choose>
      <xsl:when test="entry">
        <xsl:apply-templates select="head"/>
        <DL>
          <xsl:apply-templates select="entry"/>
        </DL>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="div[@type='subsection']">
    <xsl:call-template name="anchor"/>
    <xsl:if test="preceding-sibling::div">
      <xsl:call-template name="navpanel"/>
    </xsl:if>
    <xsl:apply-templates/>
  </xsl:template>

  <xsl:template match="div[@type='collection']">
    <xsl:call-template name="anchor"/>
    <xsl:apply-templates/>
    <P align="center">
      <xsl:text>&#x2014; &#x2020; &#x2014;</xsl:text>
    </P>
    <BR/>
  </xsl:template>

  <xsl:template match="div[@type='mon']">
    <xsl:call-template name="anchor"/>
    <xsl:call-template name="navpanel"/>
    <!--
  <H3 align="center">
    <xsl:apply-templates select="../head" mode="toc"/>
    <BR/>
    <xsl:apply-templates select="head" mode="toc"/>
  </H3>
  -->
    <xsl:apply-templates/>
  </xsl:template>

  <!-- render in table, so heading retains alignment with poems -->
  <xsl:template match="div[lg]">
    <BR/>
    <xsl:call-template name="anchor"/>
    <TABLE summary="razdelek s kiticami">
      <TR>
        <TD>
          <xsl:apply-templates select="head"/>
        </TD>
      </TR>
      <TR>
        <TD>
          <!-- this is not nice, but not(head) doesn't work!? -->
          <xsl:apply-templates select="p | lg | dateline | signature"/>
        </TD>
      </TR>
    </TABLE>
  </xsl:template>

  <xsl:template match="div[@type='part']">
    <xsl:variable name="id">
      <xsl:choose>
        <xsl:when test="@id">
          <xsl:value-of select="@id"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="generate-id(.)"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <xsl:if test="$verbose='yes'">
      <xsl:message>Processing div <xsl:value-of select="$id"/></xsl:message>
    </xsl:if>
    <xsl:choose>
      <xsl:when test="$split">
        <xsl:call-template name="outputChunk">
          <xsl:with-param name="outFile" select="$id"/>
          <xsl:with-param name="title">
            <xsl:value-of select="$def-title"/>
            <xsl:text>: </xsl:text>
            <xsl:value-of select="head"/>
            <xsl:text> (</xsl:text>
            <xsl:value-of select="$id"/>
            <xsl:text> </xsl:text>
            <xsl:value-of select="/TEI.2/teiHeader/@date.updated"/>
            <xsl:text>) </xsl:text>
          </xsl:with-param>
          <xsl:with-param name="content">
            <xsl:call-template name="chunk"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <xsl:call-template name="chunk"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- PDB start -->
  <xsl:template match="divGen[@type='para']">
    <xsl:call-template name="anchor"/>
    <HR/>
    <H2 align="center">
      <xsl:value-of select="$para-name"/>
    </H2>
    <xsl:apply-templates mode="para-mode" select="id(@corresp)/div[@corresp]"/>
  </xsl:template>

  <xsl:template mode="para-mode" match="div[@type='collection']">
    <xsl:call-template name="anchor">
      <xsl:with-param name="suffix" select="$para-suff"/>
    </xsl:call-template>
    <xsl:apply-templates mode="para-mode" select="head | div[@corresp]"/>
  </xsl:template>

  <xsl:template mode="para-mode" match="div">
    <!--[contains('facs trans dipl crit',@type) and @corresp]-->
    <BR/>
    <xsl:variable name="ids" select="concat(@id,' ',@corresp)"/>
    <xsl:variable name="facs" select="id($ids)[@type='facs']/@id"/>
    <xsl:variable name="dipl" select="id($ids)[@type='dipl']/@id"/>
    <xsl:variable name="trans" select="id($ids)[@type='trans']/@id"/>
    <xsl:variable name="crit" select="id($ids)[@type='crit']/@id"/>
    <TABLE BORDER="BORDER" summary="vzporedni prikaz">
      <COLGROUP>
        <xsl:if test="$facs">
          <COL width="20%"/>
        </xsl:if>
        <xsl:choose>
          <xsl:when test="$trans and $dipl and $crit">
            <COL span="3" width="26%"/>
          </xsl:when>
          <xsl:when
            test="($trans and $dipl) or  
                        ($trans and $crit) or  
                        ($crit and $dipl)">
            <COL span="2" width="40%"/>
          </xsl:when>
          <xsl:otherwise>
            <COL width="80*"/>
          </xsl:otherwise>
        </xsl:choose>
      </COLGROUP>
      <!--CAPTION>
      <xsl:value-of select="head"/>
    </CAPTION-->
      <TR>
        <TH colspan="99">
          <xsl:apply-templates mode="para-mode" select="head"/>
        </TH>
      </TR>
      <TR>
        <xsl:call-template name="parahead">
          <xsl:with-param name="id" select="$facs"/>
        </xsl:call-template>
        <xsl:call-template name="parahead">
          <xsl:with-param name="id" select="$dipl"/>
        </xsl:call-template>
        <xsl:call-template name="parahead">
          <xsl:with-param name="id" select="$trans"/>
        </xsl:call-template>
        <xsl:call-template name="parahead">
          <xsl:with-param name="id" select="$crit"/>
        </xsl:call-template>
      </TR>
      <TR>
        <xsl:call-template name="parabody">
          <xsl:with-param name="id" select="$facs"/>
        </xsl:call-template>
        <xsl:call-template name="parabody">
          <xsl:with-param name="id" select="$dipl"/>
        </xsl:call-template>
        <xsl:call-template name="parabody">
          <xsl:with-param name="id" select="$trans"/>
        </xsl:call-template>
        <xsl:call-template name="parabody">
          <xsl:with-param name="id" select="$crit"/>
        </xsl:call-template>
      </TR>
    </TABLE>
  </xsl:template>

  <xsl:template name="parahead">
    <xsl:param name="id"/>
    <xsl:variable name="para-id" select="id($id)/ancestor::div[@type='subsection']/@id"/>
    <xsl:if test="$id">
      <TH valign="top">
        <!--A>
        <xsl:attribute name="href">
          <xsl:call-template name="href">
            <xsl:with-param name="id" select="$para-id"/>
          </xsl:call-template>
        </xsl:attribute>
        <xsl:value-of select="id($para-id)/head/text()"/>
      </A-->
        <xsl:value-of select="id($para-id)/head/text()"/>
      </TH>
    </xsl:if>
  </xsl:template>

  <xsl:template name="parabody">
    <xsl:param name="id"/>
    <xsl:if test="$id">
      <TD valign="top">
        <!--xsl:if test="@type != 'facs' and (lg/l or p/lb)">
        <xsl:attribute name="NOWRAP">NOWRAP</xsl:attribute>
      </xsl:if-->
        <xsl:apply-templates mode="para" select="id($id)"/>
      </TD>
    </xsl:if>
  </xsl:template>

  <xsl:template mode="para" match="*">
    <xsl:apply-templates select=".">
      <xsl:with-param name="para">yes</xsl:with-param>
    </xsl:apply-templates>
  </xsl:template>
  <xsl:template mode="para" match="div">
    <xsl:call-template name="anchor">
      <xsl:with-param name="suffix" select="$para-suff"/>
    </xsl:call-template>
    <xsl:apply-templates mode="para">
      <xsl:with-param name="para">yes</xsl:with-param>
    </xsl:apply-templates>
  </xsl:template>
  <xsl:template mode="para" match="div[lg]">
    <xsl:call-template name="anchor">
      <xsl:with-param name="suffix" select="$para-suff"/>
    </xsl:call-template>
    <xsl:apply-templates>
      <xsl:with-param name="para">yes</xsl:with-param>
    </xsl:apply-templates>
  </xsl:template>

  <xsl:template mode="para-mode" match="head">
    <BR/>
    <BR/>
    <xsl:choose>
      <xsl:when test="../@type='collection'">
        <H2 align="center" class="suphead">
          <xsl:call-template name="align"/>
          <xsl:apply-templates/>
        </H2>
      </xsl:when>
      <xsl:otherwise>
        <H3 align="center">
          <U>
            <xsl:apply-templates mode="toc" select="."/>
          </U>
        </H3>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template mode="para" match="ab[figure]">
    <xsl:apply-templates select="."/>
    <BR/>
    <BR/>
    <BR/>
  </xsl:template>
  <xsl:template mode="para" match="p">
    <P>
      <xsl:call-template name="align"/>
      <xsl:apply-templates mode="para"/>
    </P>
  </xsl:template>

  <xsl:template mode="para" match="space"/>
  <xsl:template mode="para" match="space">
    <xsl:text> </xsl:text>
  </xsl:template>

  <xsl:template mode="para" match="lb">
    <xsl:if test="not(substring(.,string-length()-1,1)='-')">
      <xsl:text> </xsl:text>
    </xsl:if>
  </xsl:template>

  <xsl:template mode="para" match="text()">
    <xsl:if
      test="following-sibling::*[1][name()=lb] and
                substring(.,string-length()-1,1)='-'">
      <xsl:text>!!!</xsl:text>
    </xsl:if>
    <xsl:value-of select="."/>
  </xsl:template>

  <xsl:template match="div[@type='collection']/head">
    <BR/>
    <BR/>
    <H2 class="suphead">
      <xsl:call-template name="align"/>
      <xsl:apply-templates/>
    </H2>
  </xsl:template>

  <!--xsl:template match="ab[figure]">
  <xsl:call-template name="anchor"/>  
  <xsl:choose>
    <xsl:when test="$split">
      <xsl:variable name="outFile" select="concat($figure-prefix,@id)"/>
      <xsl:call-template name="dump-figure">
        <xsl:with-param name="$outFile"/>
      </xsl:call-template>
      <A href="{$outFile}" title="{figure[@type='small']/figDesc}">
        <IMG src="{figure[@type='thumb']/@url}"
          alt="{figure[@type='small']/figDesc}"/>
      </A>
    </xsl:when>
    <xsl:otherwise>
      <A href="{figure[@type='small']/@url}" title="{figure[@type='thumb']/figDesc}">
        <IMG src="{figure[@type='thumb']/@url}"
          alt="{figure[@type='thumb']/figDesc}"/>
      </A>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template-->

  <xsl:template name="dump-figure">
    <xsl:param name="outFile" select="concat($figure-prefix,@id)"/>
    <xsl:if test="$verbose='yes'">
      <xsl:message>Processing figure <xsl:value-of select="@id"/></xsl:message>
    </xsl:if>
    <xsl:call-template name="outputChunk">
      <xsl:with-param name="outFile" select="$outFile"/>
      <xsl:with-param name="title">
        <xsl:for-each select="ancestor::div">
          <xsl:value-of select="head/text()"/>
          <xsl:text> / </xsl:text>
        </xsl:for-each>
        <xsl:text>( </xsl:text>
        <xsl:value-of select="@id"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="/TEI.2/teiHeader/@date.updated"/>
        <xsl:text>) </xsl:text>
      </xsl:with-param>
      <xsl:with-param name="content">
        <H3>
          <xsl:for-each select="ancestor::div">
            <A>
              <xsl:attribute name="href">
                <xsl:call-template name="href"/>
              </xsl:attribute>
              <xsl:value-of select="head/text()"/>
            </A>
            <BR/>
          </xsl:for-each>
        </H3>
        <H2>
          <A href="{figure[@type='large']/@url}">
            <xsl:value-of select="figure[@type='large']/figDesc"/>
          </A>
        </H2>
        <H2>
          <xsl:value-of select="figure[@type='small']/figDesc"/>
        </H2>
        <IMG src="{figure[@type='small']/@url}" alt="{figure[@type='small']/figDesc}"/>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="div[figure]" mode="full">
    <xsl:call-template name="anchor"/>
    <TABLE border="border" summary="razdelek s slikami">
      <xsl:for-each select="figure[@type='thumb']">
        <xsl:variable name="n" select="@n"/>
        <TR>
          <TH>
            <P>
              <xsl:value-of select="../figure[@n=$n][@type='thumb']/figDesc"/>
            </P>
            <IMG src="{../figure[@n=$n][@type='thumb']/@url}"/>
          </TH>
          <TD valign="top">
            <A href="{../figure[@n=$n][@type='large']/@url}">
              <IMG src="{../figure[@n=$n][@type='small']/@url}"
                alt="{figure[@type='small']/figDesc}"/>
            </A>
          </TD>
        </TR>
      </xsl:for-each>
    </TABLE>
  </xsl:template>
  <!-- PDB end -->

  <!-- BS start -->
  <xsl:template match="page">
    <xsl:if test="@n">
      <H4>
        <xsl:value-of select="@n"/>
      </H4>
    </xsl:if>
    <TABLE summary="faksimile">
      <xsl:choose>
        <xsl:when test="figure">
          <TR>
            <TD valign="top">
              <TABLE summary="faksimile">
                <TR>
                  <TD>
                    <A href="{figure[@type='full']/@url}" title="{figure[@type='full']/figDesc}">
                      <IMG src="{figure[@type='small']/@url}" alt="{figure[@type='small']/figDesc}"
                      />
                    </A>
                  </TD>
                </TR>
                <CAPTION>
                  <xsl:value-of select="figure[@type='small']/figDesc"/>
                </CAPTION>
              </TABLE>
            </TD>
          </TR>
        </xsl:when>
        <xsl:when test="id(@corresp)/figure">
          <TR>
            <TD valign="top">
              <A href="{id(@corresp)/figure[@type='small']/@url}">
                <IMG src="{id(@corresp)/figure[@type='thmb']/@url}"
                  alt="{id(@corresp)/figure[@type='thmb']/figDesc}"/>
              </A>
            </TD>
            <TD valign="top">
              <TABLE summary="besedilo">
                <xsl:call-template name="page-text"/>
              </TABLE>
            </TD>
          </TR>
        </xsl:when>
        <xsl:otherwise>
          <xsl:call-template name="page-text"/>
        </xsl:otherwise>
      </xsl:choose>
    </TABLE>
  </xsl:template>

  <xsl:template match="line">
    <xsl:param name="para"/>
    <xsl:choose>
      <xsl:when test="..//milestone[@unit='sentence']">
        <SPAN>
          <xsl:attribute name="class">
            <xsl:call-template name="color-line"/>
          </xsl:attribute>
          <xsl:apply-templates>
            <xsl:with-param name="para" select="$para"/>
          </xsl:apply-templates>
        </SPAN>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates>
          <xsl:with-param name="para" select="$para"/>
        </xsl:apply-templates>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  <!-- BS end -->

  <xsl:template match="text//p">
    <P>
      <xsl:call-template name="align"/>
      <xsl:call-template name="anchor"/>
      <xsl:if test="@id">
        <SPAN class="parnum">
          <xsl:if test="@id">
            <xsl:attribute name="title">
              <xsl:text>ID = </xsl:text>
              <xsl:value-of select="@id"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:text>&#xA7; </xsl:text>
          <xsl:number level="any" from="text" count="p"/>
          <!--xsl:value-of select="@id"/-->
        </SPAN>
      </xsl:if>
      <xsl:apply-templates/>
    </P>
  </xsl:template>

  <xsl:template match="lg">
    <xsl:apply-templates/>
    <BR/>
  </xsl:template>

  <xsl:template match="l">
    <P class="break">
      <xsl:call-template name="span-align"/>
      <xsl:apply-templates/>
    </P>
  </xsl:template>

  <xsl:template match="table">
    <TABLE border="border" rules="all" summary="tabela">
      <xsl:apply-templates/>
    </TABLE>
  </xsl:template>

  <xsl:template match="row">
    <TR>
      <xsl:apply-templates/>
    </TR>
  </xsl:template>

  <xsl:template match="cell">
    <TD>
      <xsl:apply-templates/>
    </TD>
  </xsl:template>

  <xsl:template match="docAuthor" mode="toc">
    <xsl:if test="position() &gt; 1">
      <xsl:text> </xsl:text>
    </xsl:if>
    <xsl:apply-templates mode="toc"/>
  </xsl:template>

  <xsl:template match="head" mode="toc">
    <xsl:choose>
      <xsl:when test="position() = 2">
        <xsl:text>: </xsl:text>
      </xsl:when>
      <xsl:when test="position() = 3">
        <xsl:text>; </xsl:text>
      </xsl:when>
    </xsl:choose>
    <xsl:apply-templates mode="toc"/>
  </xsl:template>

  <xsl:template mode="toc" match="note"/>
  <xsl:template mode="toc" match="*">
    <xsl:apply-templates mode="toc"/>
  </xsl:template>
  <xsl:template mode="toc" match="text()">
    <xsl:value-of select="."/>
  </xsl:template>


  <xsl:template match="list/head">
    <H5>
      <xsl:apply-templates/>
    </H5>
  </xsl:template>
  <xsl:template match="table/head">
    <CAPTION>
      <xsl:apply-templates/>
    </CAPTION>
  </xsl:template>
  <xsl:template match="front/head">
    <H1>
      <xsl:call-template name="align"/>
      <xsl:apply-templates/>
    </H1>
  </xsl:template>
  <xsl:template match="body/head"> </xsl:template>
  <xsl:template match="div[@type='dead part']/head">
    <xsl:if test="not($split)">
      <H2>
        <xsl:call-template name="align"/>
        <xsl:apply-templates/>
      </H2>
    </xsl:if>
  </xsl:template>
  <xsl:template match="div[@type='part']/head">
    <H1 align="center">
      <xsl:apply-templates/>
    </H1>
  </xsl:template>
  <xsl:template match="div[@type='section']/head">
    <H2>
      <xsl:call-template name="align"/>
      <xsl:apply-templates/>
    </H2>
  </xsl:template>
  <xsl:template match="div[@type='subsection']/head">
    <H3>
      <xsl:call-template name="align"/>
      <xsl:apply-templates/>
    </H3>
  </xsl:template>
  <xsl:template match="div[@type='subsubsection']/head">
    <H4>
      <xsl:call-template name="align"/>
      <xsl:apply-templates/>
    </H4>
  </xsl:template>
  <xsl:template match="div[@type='mon']/head">
    <H2>
      <!--xsl:call-template name="align"/-->
      <xsl:if test="not(parent::div[1]) and ../../head">
        <xsl:apply-templates select="../../head[1]" mode="toc"/>
        <BR/>
      </xsl:if>
      <xsl:apply-templates/>
    </H2>
  </xsl:template>
  <xsl:template match="head[@type='subhead']">
    <P CLASS="subhead">
      <xsl:call-template name="align"/>
      <SMALL>
        <xsl:apply-templates/>
      </SMALL>
    </P>
  </xsl:template>
  <xsl:template
    match="div[@type='facs']/head  | 
                     div[@type='trans']/head | 
                     div[@type='dipl']/head | 
                     div[@type='crit']/head">
    <xsl:param name="para"/>
    <H3>
      <xsl:call-template name="align"/>
      <xsl:choose>
        <xsl:when test="$para and ../@corresp">
          <xsl:apply-templates mode="para"/>
          <SUP>
            <A title="Na posamezni prikaz">
              <xsl:attribute name="href">
                <xsl:call-template name="href">
                  <xsl:with-param name="id" select="../@id"/>
                </xsl:call-template>
              </xsl:attribute>
              <xsl:text>&#x2191;</xsl:text>
            </A>
          </SUP>
        </xsl:when>
        <xsl:when test="not($para) and ../@corresp">
          <xsl:apply-templates/>
          <SUP>
            <A title="Na vzporedni prikaz">
              <xsl:attribute name="href">
                <xsl:call-template name="href">
                  <xsl:with-param name="id" select="../@id"/>
                  <xsl:with-param name="suffix" select="$para-suff"/>
                </xsl:call-template>
              </xsl:attribute>
              <xsl:text>&#x2191;</xsl:text>
            </A>
          </SUP>
        </xsl:when>
        <xsl:when test="$para">
          <xsl:apply-templates mode="para"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:apply-templates/>
        </xsl:otherwise>
      </xsl:choose>
    </H3>
  </xsl:template>

  <xsl:template match="head">
    <xsl:choose>
      <xsl:when test="ancestor::div[4]">
        <H5>
          <xsl:call-template name="align"/>
          <xsl:apply-templates/>
        </H5>
      </xsl:when>
      <xsl:when test="ancestor::div[3]">
        <H4>
          <xsl:call-template name="align"/>
          <xsl:apply-templates/>
        </H4>
      </xsl:when>
      <xsl:when test="ancestor::div[2]">
        <H3>
          <xsl:call-template name="align"/>
          <xsl:apply-templates/>
        </H3>
      </xsl:when>
      <xsl:otherwise>
        <H2>
          <xsl:call-template name="align"/>
          <xsl:apply-templates/>
        </H2>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="milestone[@unit='phrase']">
    <SPAN>
      <xsl:call-template name="color-mark"/>
      <xsl:if test="id(@corresp)/@url">
        <A href="{id(@corresp)/@url}" title="Zvo&#x10D;ni zapis fraze">
          <SPAN class="sound">&#x2191;</SPAN>
          <!--xsl:text>&#x21B5;</xsl:text-->
        </A>
      </xsl:if>
    </SPAN>
    <!--xsl:if test="$debug">
    <xsl:call-template name="color-sent"/>
  </xsl:if-->
  </xsl:template>

  <xsl:template match="milestone[@unit='sentence']">
    <SPAN>
      <xsl:call-template name="color-mark"/>
      <xsl:if test="id(@corresp)/@url">
        <A href="{id(@corresp)/@url}" title="Zvo&#x10D;ni zapis povedi">
          <B>
            <SPAN class="sound">&#x2191;</SPAN>
          </B>
          <!--xsl:text>&#x21B2;</xsl:text-->
        </A>
      </xsl:if>
    </SPAN>
    <!--xsl:if test="not($debug) and not(ancestor::page)"-->
    <xsl:call-template name="color-sent"/>
    <!--/xsl:if-->
  </xsl:template>

  <xsl:template match="milestone[@unit='mon']">
    <xsl:if test="id(@corresp)/@url">
      <A href="{id(@corresp)/@url}" title="Zvo&#x10D;ni zapis celotnega spomenika">
        <SPAN class="sound">&#x2191;</SPAN>
        <!--xsl:text>&#x21B2;</xsl:text-->
      </A>
    </xsl:if>
  </xsl:template>

  <!-- NOTES -->
  <xsl:template match="text//note[@place='inline']">
    <BR/>
    <SMALL>
      <xsl:apply-templates/>
    </SMALL>
  </xsl:template>

  <xsl:template match="text//note[@place='end' or @place='foot']">
    <xsl:param name="para"/>
    <xsl:variable name="id">
      <xsl:choose>
        <xsl:when test="@id">
          <xsl:value-of select="@id"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="generate-id(.)"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <xsl:if test="not($para)">
      <xsl:call-template name="anchor">
        <xsl:with-param name="id" select="$id"/>
        <xsl:with-param name="suffix" select="@place"/>
      </xsl:call-template>
    </xsl:if>
    <SUP>
      <SPAN class="noteref">
        <SMALL>
          <xsl:if test="preceding-sibling::*[1][name(note)]">
            <xsl:text>,</xsl:text>
          </xsl:if>
          <A>
            <xsl:attribute name="href">
              <xsl:call-template name="href">
                <xsl:with-param name="id" select="$id"/>
              </xsl:call-template>
            </xsl:attribute>
            <xsl:attribute name="title">
              <xsl:value-of select="normalize-space(.)"/>
            </xsl:attribute>
            <xsl:choose>
              <xsl:when test="@rend">
                <xsl:value-of select="@rend"/>
              </xsl:when>
              <xsl:otherwise>
                <xsl:number level="any" count="note" from="div[@type='part']"/>
              </xsl:otherwise>
            </xsl:choose>
          </A>
        </SMALL>
      </SPAN>
    </SUP>
    <xsl:if test="not(preceding-sibling::*[1][name(note)])">
      <xsl:text> </xsl:text>
    </xsl:if>
  </xsl:template>

  <xsl:template match="note" mode="show">
    <xsl:variable name="id">
      <xsl:choose>
        <xsl:when test="@id">
          <xsl:value-of select="@id"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="generate-id(.)"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <LI>
      <xsl:call-template name="anchor"/>
      <xsl:apply-templates/>
      <A href="#{$id}{@place}">
        <xsl:text>&#x2191;</xsl:text>
      </A>
    </LI>
  </xsl:template>

  <xsl:template match="titlePage">
    <HR/>
    <xsl:apply-templates/>
    <HR/>
  </xsl:template>

  <xsl:template match="docTitle">
    <xsl:apply-templates/>
  </xsl:template>

  <xsl:template match="titlePart">
    <H1 align="center">
      <xsl:apply-templates/>
    </H1>
  </xsl:template>

  <xsl:template match="docImprint">
    <H3 align="center">
      <xsl:apply-templates/>
    </H3>
  </xsl:template>

  <xsl:template match="div[@type='part']/docAuthor">
    <H3 align="center">
      <xsl:apply-templates/>
    </H3>
  </xsl:template>

  <xsl:template match="docAuthor">
    <H5>
      <xsl:apply-templates/>
    </H5>
  </xsl:template>

  <xsl:template match="text//name">
    <xsl:param name="para"/>
    <xsl:if test="not($para)">
      <xsl:call-template name="anchor"/>
    </xsl:if>
    <xsl:choose>
      <xsl:when test="$debug">
        <FONT color="GoldenRod">
          <xsl:apply-templates/>
        </FONT>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates/>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:if test="@corresp">
      <SUP>
        <A title="Na imensko kazalo">
          <xsl:attribute name="href">
            <xsl:call-template name="href">
              <xsl:with-param name="id" select="@corresp"/>
            </xsl:call-template>
          </xsl:attribute>
          <xsl:text>&#x2191;</xsl:text>
        </A>
      </SUP>
    </xsl:if>
  </xsl:template>

  <xsl:template match="dateline | signature">
    <P>
      <I>
        <xsl:choose>
          <xsl:when test="$debug">
            <FONT color="violet">
              <xsl:apply-templates/>
            </FONT>
          </xsl:when>
          <xsl:otherwise>
            <xsl:apply-templates/>
          </xsl:otherwise>
        </xsl:choose>
      </I>
    </P>
  </xsl:template>

  <xsl:template match="text//date">
    <xsl:choose>
      <xsl:when test="$debug">
        <FONT color="violet">
          <xsl:apply-templates/>
        </FONT>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="foreign">
    <xsl:choose>
      <xsl:when test="$debug">
        <FONT color="fuchsia">
          <xsl:apply-templates/>
        </FONT>
      </xsl:when>
      <xsl:otherwise>
        <I>
          <xsl:apply-templates/>
        </I>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- Janus elements: del/add sic/corr abbr/exp -->
  <xsl:template match="del">
    <xsl:choose>
      <xsl:when test="following-sibling::*[1][self::add]"/>
      <xsl:otherwise>
        <SPAN style="text-decoration: line-through;" class="janus">
          <xsl:attribute name="title">
            <xsl:text>izbrisal pisar</xsl:text>
            <xsl:call-template name="del-type"/>
            <!--xsl:call-template name="resp"/-->
          </xsl:attribute>
          <xsl:apply-templates/>
        </SPAN>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  <xsl:template match="del" mode="show">
    <xsl:apply-templates/>
  </xsl:template>
  <xsl:template match="add">
    <SPAN class="janus">
      <xsl:attribute name="title">
        <xsl:call-template name="add-place"/>
        <xsl:choose>
          <xsl:when test="preceding-sibling::*[1][self::del]">
            <xsl:text>pisar popravil iz: "</xsl:text>
            <xsl:apply-templates mode="show" select="preceding-sibling::del[1]"/>
            <xsl:text>"</xsl:text>
            <xsl:call-template name="del-type">
              <xsl:with-param name="type" select="preceding-sibling::del[1]/@type"/>
            </xsl:call-template>
          </xsl:when>
          <xsl:otherwise>
            <xsl:text>dodal pisar</xsl:text>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="@place='sup'">
          <SUP>
            <xsl:call-template name="cert-in"/>
            <xsl:apply-templates/>
            <xsl:call-template name="cert-out"/>
          </SUP>
        </xsl:when>
        <xsl:otherwise>
          <xsl:call-template name="cert-in"/>
          <xsl:apply-templates/>
          <xsl:call-template name="cert-out"/>
        </xsl:otherwise>
      </xsl:choose>
    </SPAN>
  </xsl:template>

  <xsl:template match="sic">
    <xsl:if test="not(following-sibling::*[1][self::corr])">
      <SPAN style="text-decoration: line-through;" class="janus">
        <xsl:attribute name="title">
          <xsl:text>izbrisal avtor prepisa</xsl:text>
          <xsl:call-template name="resp"/>
        </xsl:attribute>
        <xsl:apply-templates/>
      </SPAN>
    </xsl:if>
  </xsl:template>
  <xsl:template match="sic" mode="show">
    <xsl:apply-templates/>
  </xsl:template>
  <xsl:template match="corr">
    <SPAN class="janus">
      <xsl:attribute name="title">
        <xsl:choose>
          <xsl:when test="preceding-sibling::*[1][self::sic]">
            <xsl:text>popravil avtor prepisa iz: "</xsl:text>
            <xsl:apply-templates mode="show" select="preceding-sibling::sic[1]"/>
            <xsl:text>"</xsl:text>
            <xsl:call-template name="resp"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:text>dodal avtor prepisa</xsl:text>
          </xsl:otherwise>
        </xsl:choose>
        <xsl:call-template name="cert-text"/>
      </xsl:attribute>
      <xsl:call-template name="cert-in"/>
      <xsl:apply-templates/>
      <xsl:call-template name="cert-out"/>
      <xsl:text/>
    </SPAN>
  </xsl:template>

  <xsl:template match="abbr">
    <xsl:if test="not(following-sibling::*[1][self::expan])">
      <SPAN class="janus">
        <xsl:attribute name="title">
          <xsl:call-template name="abbr-type"/>
          <xsl:if test="@expan">
            <xsl:text>razvezano: "</xsl:text>
            <xsl:value-of select="@expan"/>
            <xsl:text>"</xsl:text>
          </xsl:if>
        </xsl:attribute>
        <xsl:apply-templates/>
      </SPAN>
    </xsl:if>
  </xsl:template>
  <xsl:template match="*" mode="show">
    <xsl:apply-templates/>
  </xsl:template>
  <xsl:template match="expan">
    <SPAN class="janus">
      <xsl:attribute name="title">
        <xsl:choose>
          <xsl:when test="preceding-sibling::*[1][self::abbr]">
            <xsl:call-template name="abbr-type">
              <xsl:with-param name="type" select="preceding-sibling::abbr[1]/@type"/>
            </xsl:call-template>
            <xsl:text>avtor prepisa razvezal iz: "</xsl:text>
            <xsl:apply-templates mode="show" select="preceding-sibling::abbr[1]"/>
            <xsl:text>"</xsl:text>
          </xsl:when>
          <xsl:when test="@abbr">
            <xsl:text>razvezano iz: "</xsl:text>
            <xsl:apply-templates mode="show" select="@abbr"/>
            <xsl:text>"</xsl:text>
          </xsl:when>
          <xsl:otherwise>
            <xsl:text>ni podatkov</xsl:text>
          </xsl:otherwise>
        </xsl:choose>
        <xsl:call-template name="cert-text"/>
      </xsl:attribute>
      <xsl:call-template name="cert-in"/>
      <xsl:apply-templates/>
      <xsl:call-template name="cert-out"/>
    </SPAN>
  </xsl:template>

  <xsl:template name="del-type">
    <xsl:param name="type" select="@type"/>
    <xsl:if test="$type">
      <xsl:text> /</xsl:text>
      <xsl:choose>
        <xsl:when test="$type='errasure'">razura</xsl:when>
        <xsl:when test="$type='correction'">popravek</xsl:when>
      </xsl:choose>
      <xsl:text>/ </xsl:text>
    </xsl:if>
  </xsl:template>
  <xsl:template name="add-place">
    <xsl:param name="place" select="@place"/>
    <xsl:if test="$place">
      <xsl:choose>
        <xsl:when test="$place='inline'">vpisano</xsl:when>
        <xsl:when test="$place='sup'">nadpisano</xsl:when>
      </xsl:choose>
      <xsl:text>; </xsl:text>
    </xsl:if>
  </xsl:template>
  <xsl:template name="abbr-type">
    <xsl:param name="type" select="@type"/>
    <xsl:if test="$type">
      <xsl:choose>
        <xsl:when test="$type='brevigraph'">brevigraf</xsl:when>
        <xsl:when test="$type='contraction'">kontrakcija</xsl:when>
        <xsl:when test="$type='suspension'">suspenzija</xsl:when>
      </xsl:choose>
      <xsl:text>; </xsl:text>
    </xsl:if>
  </xsl:template>
  <xsl:template name="cert-text">
    <xsl:if test="@cert">
      <xsl:text> /</xsl:text>
      <xsl:choose>
        <xsl:when test="@cert='hi'">zanesljiva rekonstrukcija</xsl:when>
        <xsl:when test="@cert='mid'">verjetna rekonstrukcija</xsl:when>
        <xsl:when test="@cert='low'">nezanesljiva rekonstrukcija</xsl:when>
      </xsl:choose>
      <xsl:text>/ </xsl:text>
    </xsl:if>
  </xsl:template>
  <xsl:template name="cert-in">
    <!--xsl:choose>
    <xsl:when test="@cert='hi'">[</xsl:when>
    <xsl:when test="@cert='mid'">&lt;</xsl:when>
    <xsl:when test="@cert='low'">(</xsl:when>
    <xsl:otherwise>(</xsl:otherwise>
  </xsl:choose-->
  </xsl:template>
  <xsl:template name="cert-out">
    <!--xsl:choose>
    <xsl:when test="@cert='hi'">]</xsl:when>
    <xsl:when test="@cert='mid'">&gt;</xsl:when>
    <xsl:when test="@cert='low'">)</xsl:when>
    <xsl:otherwise>)</xsl:otherwise>
  </xsl:choose-->
  </xsl:template>

  <xsl:template name="resp">
    <xsl:if test="@resp">
      <xsl:text> (popravil: </xsl:text>
      <xsl:choose>
        <xsl:when test="id(@resp)">
          <xsl:value-of select="normalize-space(id(@resp))"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="@resp"/>
        </xsl:otherwise>
      </xsl:choose>
      <xsl:text>)</xsl:text>
    </xsl:if>
  </xsl:template>
  <!-- end of Janus -->

  <xsl:template match="lb">
    <BR/>
  </xsl:template>

  <xsl:template match="space">
    <xsl:call-template name="space">
      <xsl:with-param name="n" select="round(@extent div 1.1)"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="hi">
    <xsl:param name="para"/>
    <xsl:choose>
      <xsl:when test="@rend='sup' or @rend='superscript'">
        <SUP>
          <xsl:apply-templates>
            <xsl:with-param name="para">yes</xsl:with-param>
          </xsl:apply-templates>
        </SUP>
      </xsl:when>
      <xsl:when test="@rend='it' or @rend='italic'">
        <I>
          <xsl:apply-templates>
            <xsl:with-param name="para">yes</xsl:with-param>
          </xsl:apply-templates>
        </I>
      </xsl:when>
      <xsl:otherwise>
        <I>
          <xsl:apply-templates>
            <xsl:with-param name="para">yes</xsl:with-param>
          </xsl:apply-templates>
        </I>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="emph">
    <xsl:param name="para"/>
    <xsl:choose>
      <xsl:when test="@rend = 'italic'">
        <I>
          <xsl:apply-templates>
            <xsl:with-param name="para">yes</xsl:with-param>
          </xsl:apply-templates>
        </I>
      </xsl:when>
      <xsl:when test="@rend = 'underline'">
        <U>
          <xsl:apply-templates>
            <xsl:with-param name="para">yes</xsl:with-param>
          </xsl:apply-templates>
        </U>
      </xsl:when>
      <xsl:when test="@rend = 'bold'">
        <B>
          <xsl:apply-templates>
            <xsl:with-param name="para">yes</xsl:with-param>
          </xsl:apply-templates>
        </B>
      </xsl:when>
      <xsl:when test="contains(@rend,'dblu')">
        <U>
          <xsl:apply-templates>
            <xsl:with-param name="para">yes</xsl:with-param>
          </xsl:apply-templates>
        </U>
      </xsl:when>
      <xsl:when test="@rend = 'u'">
        <U>
          <xsl:apply-templates>
            <xsl:with-param name="para">yes</xsl:with-param>
          </xsl:apply-templates>
        </U>
      </xsl:when>
      <xsl:otherwise>
        <EM>
          <xsl:apply-templates>
            <xsl:with-param name="para">yes</xsl:with-param>
          </xsl:apply-templates>
        </EM>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="gap">
    <xsl:text>[&#x2026;]</xsl:text>
  </xsl:template>

  <xsl:template match="supplied">
    <xsl:text> !!!</xsl:text>
    <xsl:apply-templates/>
    <xsl:text>!!! </xsl:text>
  </xsl:template>

  <xsl:template match="list">
    <xsl:if test="parent::p">
      <!-- HTML doesn't support lists inside paragraphs -->
      <xsl:text disable-output-escaping="yes">&lt;/p&gt;</xsl:text>
    </xsl:if>
    <xsl:apply-templates select="head"/>
    <xsl:choose>
      <xsl:when test="label">
        <DL>
          <xsl:apply-templates select="label | item"/>
        </DL>
      </xsl:when>
      <xsl:when test="@type='numbered' or @type='ordered'">
        <OL>
          <xsl:apply-templates select="item"/>
        </OL>
      </xsl:when>
      <xsl:otherwise>
        <UL>
          <xsl:apply-templates select="item"/>
        </UL>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:if test="parent::p">
      <xsl:text disable-output-escaping="yes">&lt;p&gt;</xsl:text>
    </xsl:if>
  </xsl:template>

  <xsl:template match="text//list/label">
    <DT>
      <xsl:if test="@id">
        <xsl:call-template name="anchor"/>
      </xsl:if>
      <B>
        <xsl:apply-templates/>
      </B>
    </DT>
  </xsl:template>

  <xsl:template match="text//item">
    <xsl:choose>
      <xsl:when test="preceding-sibling::label">
        <DD>
          <xsl:apply-templates/>
        </DD>
      </xsl:when>
      <xsl:otherwise>
        <LI>
          <xsl:apply-templates/>
        </LI>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- bsBK-nam NAME RESOLUTION -->
  <xsl:template match="div[@id='bsBK-nam']//item">
    <xsl:variable name="nid" select=".//name[1]/@id"/>
    <LI>
      <xsl:if test="$nid">
        <xsl:call-template name="anchor">
          <xsl:with-param name="id" select="$nid"/>
        </xsl:call-template>
        <xsl:if test="$debug">
          <xsl:value-of select="$nid"/>
          <xsl:text> </xsl:text>
        </xsl:if>
      </xsl:if>
      <B>
        <xsl:value-of select=".//name"/>
      </B>
      <xsl:choose>
        <xsl:when test="ref[@type='name']">
          <xsl:apply-templates select="text() | ref"/>
        </xsl:when>
        <xsl:otherwise>
          <UL>
            <xsl:if test="ref[@type='bib']">
              <LI>
                <xsl:for-each select="ref[@type='bib']">
                  <xsl:if test="position() &gt; 1">,</xsl:if>
                  <xsl:text> [</xsl:text>
                  <A>
                    <xsl:attribute name="href">
                      <xsl:call-template name="href">
                        <xsl:with-param name="id" select="@target"/>
                      </xsl:call-template>
                    </xsl:attribute>
                    <xsl:attribute name="title">
                      <!--xsl:for-each select="id(@target)/ancestor-or-self::div">
                         <xsl:value-of select="head[1]/text()"/>
                         <xsl:text> / </xsl:text>
                       </xsl:for-each-->
                      <xsl:value-of select="id(@target)//author[1]"/>
                      <xsl:text>: </xsl:text>
                      <xsl:value-of select="id(@target)//title[1]"/>
                    </xsl:attribute>
                    <xsl:value-of select="id(@target)/@n"/>
                  </A>
                  <xsl:text>]</xsl:text>
                </xsl:for-each>
              </LI>
            </xsl:if>
            <xsl:if test="ref[@type='pages'] and $debug">
              <LI>
                <xsl:text>(</xsl:text>
                <xsl:value-of select="ref[@type='pages']/@n"/>
                <xsl:text>) </xsl:text>
                <xsl:apply-templates select="ref[@type='pages']"/>
              </LI>
            </xsl:if>
            <xsl:if test="ref[name][@target]">
              <LI>
                <xsl:choose>
                  <xsl:when test="$debug">
                    <TABLE summary="reference imen">
                      <xsl:for-each select="id(ref[name]/@target)">
                        <TR>
                          <TD>
                            <xsl:value-of select="@id"/>
                          </TD>
                          <TD>
                            <xsl:for-each select="id(@id)/ancestor::div">
                              <xsl:apply-templates mode="toc" select="head[1]"/>
                              <xsl:text> / </xsl:text>
                            </xsl:for-each>
                            <xsl:text>&#xA7; </xsl:text>
                            <xsl:number level="any" select="id(@id)/ancestor::p"/>
                            <A title="... {.} ...">
                              <xsl:attribute name="href">
                                <xsl:call-template name="href"/>
                              </xsl:attribute>
                              <xsl:text>&#x2191;</xsl:text>
                            </A>
                          </TD>
                          <TD>
                            <I>
                              <xsl:value-of select="."/>
                            </I>
                          </TD>
                        </TR>
                      </xsl:for-each>
                    </TABLE>
                  </xsl:when>
                  <xsl:otherwise>
                    <xsl:for-each select="id(ref[name]/@target)">
                      <xsl:if test="position() &gt; 1">, </xsl:if>
                      <A>
                        <xsl:attribute name="href">
                          <xsl:call-template name="href"/>
                        </xsl:attribute>
                        <xsl:variable name="head-ladder">
                          <xsl:for-each select="id(@id)/ancestor::div">
                            <xsl:apply-templates mode="toc" select="head[1]"/>
                            <xsl:text> / </xsl:text>
                          </xsl:for-each>
                          <xsl:call-template name="concord"/>
                        </xsl:variable>
                        <xsl:attribute name="title">
                          <xsl:value-of select="normalize-space($head-ladder)"/>
                        </xsl:attribute>
                        <xsl:choose>
                          <xsl:when test="ancestor::head or ancestor::docAuthor or ancestor::byline">
                            <xsl:text>*</xsl:text>
                            <xsl:number level="multiple" count="div"/>
                          </xsl:when>
                          <xsl:when test="ancestor::note">
                            <xsl:text>&#x2021;</xsl:text>
                            <xsl:number level="any" count="div[@type='part']"/>
                            <xsl:text>.</xsl:text>
                            <xsl:number level="any" count="note" from="div[@type='part']"/>
                          </xsl:when>
                          <xsl:when test="ancestor::line">
                            <xsl:value-of select="ancestor::page/@n"/>
                            <xsl:text>|</xsl:text>
                            <xsl:value-of select="ancestor::line/@n"/>
                          </xsl:when>
                          <xsl:when test="ancestor::p">
                            <xsl:text>&#xA7;</xsl:text>
                            <xsl:number level="any" from="text" count="p"/>
                          </xsl:when>
                          <xsl:when test="ancestor::div">
                            <xsl:number level="multiple" count="div"/>
                          </xsl:when>
                          <xsl:otherwise>
                            <xsl:text>???</xsl:text>
                          </xsl:otherwise>
                        </xsl:choose>
                      </A>
                    </xsl:for-each>
                  </xsl:otherwise>
                </xsl:choose>
              </LI>
            </xsl:if>
            <xsl:if test="xref">
              <LI>
                <xsl:for-each select="xref">
                  <xsl:if test="position() &gt; 1">,</xsl:if>
                  <xsl:text> </xsl:text>
                  <xsl:apply-templates select="."/>
                </xsl:for-each>
              </LI>
            </xsl:if>
          </UL>
        </xsl:otherwise>
      </xsl:choose>
    </LI>
  </xsl:template>

  <!-- BIBLIOGRAHPY -->
  <xsl:template match="text//listBibl">
    <xsl:if test="parent::p">
      <!-- HTML doesn't support lists inside paragraphs -->
      <xsl:text disable-output-escaping="yes">&lt;/p&gt;</xsl:text>
    </xsl:if>
    <UL>
      <xsl:apply-templates/>
    </UL>
    <!--OL>
    <xsl:if test="./biblStruct/@n">
      <xsl:attribute name="start">
        <xsl:value-of select="biblStruct/@n"/>
      </xsl:attribute>
    </xsl:if>
    <xsl:apply-templates/>
  </OL-->
    <xsl:if test="parent::p">
      <xsl:text disable-output-escaping="yes">&lt;p&gt;</xsl:text>
    </xsl:if>
  </xsl:template>

  <xsl:template match="listBibl/bibl">
    <LI>
      <xsl:call-template name="anchor"/>
      <xsl:apply-templates/>
    </LI>
  </xsl:template>

  <xsl:template match="text//bibl">
    <xsl:choose>
      <xsl:when test="$debug">
        <FONT color="green">
          <xsl:apply-templates/>
        </FONT>
      </xsl:when>
      <xsl:otherwise>
        <I>
          <xsl:apply-templates/>
        </I>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="biblStruct">
    <LI>
      <A NAME="{@id}">
        <xsl:if test="@n">
          <xsl:value-of select="@n"/>
          <xsl:text>. </xsl:text>
        </xsl:if>
      </A>
      <xsl:if test="$debug">
        <xsl:text>&#9;[</xsl:text>
        <xsl:value-of select="@id"/>
        <xsl:text>] </xsl:text>
      </xsl:if>
      <xsl:apply-templates/>
    </LI>
  </xsl:template>

  <xsl:template match="author">
    <B>
      <xsl:apply-templates/>
    </B>
    <xsl:if test="not( normalize-space(.) = '–')">
      <xsl:text>: </xsl:text>
    </xsl:if>
  </xsl:template>

  <xsl:template match="signed | dateline">
    <P style="text-indent:2em">
      <xsl:call-template name="align"/>
      <xsl:apply-templates/>
    </P>
  </xsl:template>

  <xsl:template match="text//analytic/title">
    <xsl:text> </xsl:text>
    <xsl:choose>
      <xsl:when test="$debug">
        <FONT color="green">
          <xsl:apply-templates/>
        </FONT>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="text//monogr/title">
    <xsl:text> </xsl:text>
    <xsl:choose>
      <xsl:when test="$debug">
        <FONT color="green">
          <xsl:apply-templates/>
        </FONT>
      </xsl:when>
      <xsl:otherwise>
        <I>
          <xsl:apply-templates/>
        </I>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="text//pubPlace">
    <xsl:text> </xsl:text>
    <xsl:choose>
      <xsl:when test="$debug">
        <FONT color="fuchsia">
          <xsl:apply-templates/>
        </FONT>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="text//biblScope">
    <xsl:text> </xsl:text>
    <xsl:choose>
      <xsl:when test="$debug">
        <FONT color="blue">
          <xsl:apply-templates/>
        </FONT>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- POINTING -->

  <xsl:template match="ref">
    <U>
      <xsl:apply-templates/>
    </U>
  </xsl:template>

  <xsl:template match="ref[@target]">
    <xsl:apply-templates/>
    <SUP>
      <xsl:for-each select="id(@target)">
        <A>
          <xsl:attribute name="href">
            <xsl:call-template name="href"/>
          </xsl:attribute>
          <xsl:attribute name="title">
            <xsl:for-each select="ancestor-or-self::div">
              <xsl:value-of select="head/text()"/>
              <xsl:text> / </xsl:text>
            </xsl:for-each>
          </xsl:attribute>
          <xsl:text>&#x2191;</xsl:text>
        </A>
      </xsl:for-each>
    </SUP>
  </xsl:template>

  <xsl:template match="ptr">
    <xsl:choose>
      <xsl:when test="@target">
        <xsl:for-each select="id(@target)">
          <A>
            <xsl:attribute name="href">
              <xsl:call-template name="href"/>
            </xsl:attribute>
            <xsl:attribute name="title">
              <xsl:for-each select="ancestor-or-self::div">
                <xsl:value-of select="head/text()"/>
                <xsl:text> / </xsl:text>
              </xsl:for-each>
            </xsl:attribute>
            <xsl:text>&#x2191;</xsl:text>
          </A>
        </xsl:for-each>
      </xsl:when>
      <xsl:otherwise>
        <FONT color="red">&#x2191;?</FONT>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="xref">
    <U>
      <xsl:choose>
        <xsl:when test="@url">
          <A href="{@url}">
            <xsl:apply-templates/>
          </A>
        </xsl:when>
        <xsl:otherwise>
          <xsl:apply-templates/>
        </xsl:otherwise>
      </xsl:choose>
    </U>
  </xsl:template>

  <xsl:template match="xptr">
    <xsl:if test="@url">
      <A href="{@url}">
        <xsl:text>&#x2191;</xsl:text>
        <!--
      <U>
        <xsl:choose>
          <xsl:when test="@id">
            <xsl:value-of select="@id"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="@url"/>
          </xsl:otherwise>
        </xsl:choose>
      </U>
      -->
      </A>
    </xsl:if>
  </xsl:template>

  <!-- TEI.DICTIONARIES -->
  <xsl:template mode="toc" match="div[@type='dict']">
    <LI>
      <xsl:apply-templates mode="toc" select=".//entry"/>
    </LI>
  </xsl:template>

  <xsl:template match="div[@type='dict']">
    <xsl:apply-templates select="head"/>
    <DL>
      <xsl:apply-templates/>
    </DL>
  </xsl:template>

  <xsl:template mode="toc" match="entry">
    <xsl:variable name="prev"
      select="translate(substring(
                preceding-sibling::entry[1]/@key,1,1),
                'ABCDEFGHIJKLMNOPQRSWXYZ',
                'abcdefghijklmnopqrswxyz')
                "/>
    <xsl:variable name="this"
      select="translate(substring(
              @key,1,1),
              'ABCDEFGHIJKLMNOPQRSWXYZ',
              'abcdefghijklmnopqrswxyz')
              "/>
    <xsl:if test="not($prev = $this)">
      <xsl:if test="$prev">
        <xsl:text>, </xsl:text>
      </xsl:if>
      <A href="#{@id}">
        <xsl:value-of
          select="translate($this,
                  'abcdefghijklmnopqrstuvwxyz',
                  'ABCDEFGHIJKLMNOPQRSTUVWXYZ')
                  "
        />
      </A>
    </xsl:if>
  </xsl:template>

  <xsl:template match="entry">
    <DT>
      <SUP>
        <SPAN class="meta">
          <xsl:number/>
        </SPAN>
      </SUP>
      <A name="{@id}">
        <xsl:apply-templates select="form[1]"/>
      </A>
      <xsl:apply-templates select="gramGrp"/>
      <xsl:apply-templates select="form[2]"/>
      <xsl:apply-templates select="xr"/>
    </DT>
    <xsl:if test="trans or eg">
      <DD>
        <xsl:apply-templates select="trans"/>
        <xsl:if test="eg">
          <UL>
            <xsl:apply-templates select="eg"/>
          </UL>
        </xsl:if>
      </DD>
    </xsl:if>
  </xsl:template>

  <xsl:template match="form">
    <xsl:apply-templates/>
  </xsl:template>

  <xsl:template match="form/orth">
    <B>
      <xsl:apply-templates/>
    </B>
    <xsl:text> </xsl:text>
  </xsl:template>

  <xsl:template match="form/pron">
    <SMALL>
      <xsl:text> [</xsl:text>
      <xsl:apply-templates/>
      <xsl:text>] </xsl:text>
    </SMALL>
  </xsl:template>

  <xsl:template match="gram">
    <SMALL>
      <xsl:apply-templates/>
    </SMALL>
    <xsl:if test="ancestor::eg">
      <BR/>
    </xsl:if>
  </xsl:template>

  <xsl:template match="trans">
    <xsl:apply-templates/>
  </xsl:template>

  <xsl:template match="tr">
    <xsl:choose>
      <xsl:when test="@lang='ocs'">
        <SPAN class="ocs">
          <xsl:apply-templates/>
        </SPAN>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates/>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:if test="@lang">
      <SUB>
        <SPAN class="meta">
          <xsl:value-of select="@lang"/>
        </SPAN>
      </SUB>
    </xsl:if>
    <xsl:if test="following-sibling::tr">
      <xsl:text> | </xsl:text>
    </xsl:if>
  </xsl:template>

  <xsl:template match="eg">
    <LI>
      <xsl:apply-templates/>
    </LI>
  </xsl:template>

  <xsl:template match="q">
    <xsl:text>"</xsl:text>
    <xsl:apply-templates/>
    <xsl:text>"</xsl:text>
  </xsl:template>

  <xsl:template match="entry//q">
    <xsl:choose>
      <xsl:when test="@corresp">
        <A>
          <xsl:attribute name="href">
            <xsl:call-template name="href">
              <xsl:with-param name="id" select="@corresp"/>
            </xsl:call-template>
          </xsl:attribute>
          <SPAN class="meta">
            <xsl:value-of select="@n"/>
          </SPAN>
        </A>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="@n"/>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:text>: </xsl:text>
    <xsl:apply-templates/>
    <!--could make a link to WAV, but directly in LX, and needs hand validation-->
    <!--xsl:if test="id(@corresp)/milestone[@unit='sentence']/-->
    <xsl:if test="following-sibling::q">
      <BR/>
    </xsl:if>
  </xsl:template>

  <xsl:template match="lbl">
    <xsl:apply-templates/>
  </xsl:template>

  <xsl:template match="xr">
    <xsl:text>&#x2192; </xsl:text>
    <xsl:apply-templates/>
  </xsl:template>


  <xsl:template match="g[text()]">
    <xsl:apply-templates/>
  </xsl:template>

  <xsl:template match="g">
    <xsl:param name="g_encoding" select="$ENCODING"/>
    <xsl:variable name="glyph" select="id(@corresp)/mapping[@type=$ENCODING]"/>
    <xsl:variable name="stand" select="id(@corresp)/mapping[@type='standard']"/>
    <xsl:choose>
      <xsl:when test="ancestor::abbr or ancestor::expan">
        <xsl:value-of select="$glyph"/>
      </xsl:when>
      <!-- we are in title attribute, can't choose font there -->
      <xsl:when test="ancestor::sic or ancestor::corr">
        <xsl:value-of select="$stand"/>
      </xsl:when>
      <xsl:otherwise>
        <SPAN>
          <xsl:if test="$ENCODING = 'standard'">
            <xsl:attribute name="class">
              <xsl:value-of select="id(@corresp)/charProp[localName='mapping']/value"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="title">
            <xsl:value-of select="id(@corresp)/charProp[localName='font']/value"/>
            <xsl:text>: </xsl:text>
            <xsl:value-of select="id(@corresp)/charName"/>
          </xsl:attribute>
          <xsl:value-of select="$glyph"/>
        </SPAN>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- NAMED TEMPLATES -->
  <xsl:template name="space">
    <xsl:param name="n"/>
    <xsl:if test="$n">
      <xsl:text>&#xA0;</xsl:text>
      <xsl:call-template name="space">
        <xsl:with-param name="n" select="$n - 1"/>
      </xsl:call-template>
    </xsl:if>
    <!--Better alternative, but works only at BOL:
       <P style="text-indent: $n / 4 em">
      Also, have to triger it from p/l level
  -->
  </xsl:template>

  <xsl:template name="align">
    <xsl:if test="@rend = 'right' or @rend = 'center' or @rend = 'justify'">
      <xsl:attribute name="align">
        <xsl:value-of select="@rend"/>
      </xsl:attribute>
    </xsl:if>
  </xsl:template>

  <xsl:template name="span-align">
    <xsl:if test="@rend = 'right' or @rend = 'center' or @rend = 'justify'">
      <xsl:attribute name="style">
        <xsl:text>text-align: </xsl:text>
        <xsl:value-of select="@rend"/>
        <xsl:text>;</xsl:text>
      </xsl:attribute>
    </xsl:if>
  </xsl:template>

  <xsl:template name="rend">
    <xsl:param name="rend" select="@rend"/>
    <xsl:variable name="rest" select="string-after($rend,' ')"/>
    <xsl:variable name="first">
      <xsl:choose>
        <xsl:when test="$rest">
          <xsl:value-of select="substring-before($rend,' ')"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:variable name="first" select="$rend"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <xsl:if test="$first">
      <xsl:choose>
        <xsl:when test="$first = 'bold'">
          <B>
            <xsl:call-template name="rend">
              <xsl:with-param name="rend" select="$rest"/>
            </xsl:call-template>
          </B>
        </xsl:when>
        <xsl:when test="$first = 'italic'">
          <I>
            <xsl:call-template name="rend">
              <xsl:with-param name="rend" select="$rest"/>
            </xsl:call-template>
          </I>
        </xsl:when>
        <xsl:when test="$first = 'underline'">
          <U>
            <xsl:call-template name="rend">
              <xsl:with-param name="rend" select="$rest"/>
            </xsl:call-template>
          </U>
        </xsl:when>
      </xsl:choose>
    </xsl:if>
  </xsl:template>

  <xsl:template name="toc-main">
    <xsl:param name="head">Kazalo</xsl:param>
    <xsl:param name="level">2</xsl:param>
    <xsl:param name="prefix"/>
    <H2>
      <xsl:value-of select="$head"/>
    </H2>
    <xsl:if test="//teiHeader and $level &lt; 3">
      <UL>
        <!--xsl:if test="//teiHeader//@lang='en'">
        <LI>
          <A HREF="{$teiHeader-en}.html"/>
          <xsl:value-of select="$teiHeader-desc-en"/>
        </LI>
      </xsl:if-->
        <LI>
          <A>
            <xsl:attribute name="href">
              <xsl:call-template name="href">
                <xsl:with-param name="id" select="//teiHeader/@id"/>
              </xsl:call-template>
            </xsl:attribute>
            <xsl:value-of select="$teiHeader-desc-sl"/>
          </A>
        </LI>
      </UL>
    </xsl:if>
    <UL>
      <xsl:apply-templates mode="toc" select="//body/div">
        <xsl:with-param name="level" select="$level"/>
        <xsl:with-param name="prefix" select="$prefix"/>
      </xsl:apply-templates>
    </UL>
    <xsl:if test="//back">
      <xsl:text>Dodatki:</xsl:text>
      <UL>
        <xsl:apply-templates mode="toc" select="//back/div">
          <xsl:with-param name="level" select="$level"/>
          <xsl:with-param name="prefix" select="$prefix"/>
        </xsl:apply-templates>
      </UL>
    </xsl:if>
  </xsl:template>

  <xsl:template name="chunk">
    <xsl:call-template name="anchor"/>
    <xsl:apply-templates select="head"/>
    <xsl:apply-templates select="docAuthor"/>
    <xsl:call-template name="navpanel"/>
    <xsl:if test="div[head] | divGen | .//note[@place='end' or @place='foot']">
      <H3>
        <xsl:value-of select="$toc-div"/>
      </H3>
      <UL>
        <xsl:apply-templates mode="toc" select="div | divGen">
          <xsl:with-param name="level">1</xsl:with-param>
        </xsl:apply-templates>
        <xsl:if test=".//note[@place='end' or @place='foot']">
          <LI>
            <A href="#{@id}.notes">
              <!--xsl:value-of select="head[1]"/-->
              <!--xsl:text> - </xsl:text-->
              <xsl:text>Opombe</xsl:text>
            </A>
          </LI>
        </xsl:if>
      </UL>
    </xsl:if>
    <xsl:apply-templates select="*[name() != 'head']"/>
    <xsl:if test=".//note[@place='end' or @place='foot'][1]">
      <A name="{@id}.notes"/>
      <H3>Opombe</H3>
      <OL>
        <xsl:apply-templates select=".//note[@place='end' or @place='foot']" mode="show"/>
      </OL>
      <xsl:if test="$split">
        <BR/>
        <BR/>
        <BR/>
        <BR/>
        <BR/>
        <BR/>
        <BR/>
        <BR/>
        <BR/>
        <BR/>
        <BR/>
        <BR/>
        <BR/>
        <BR/>
      </xsl:if>
    </xsl:if>
    <xsl:call-template name="navpanel"/>
  </xsl:template>

  <xsl:template name="navpanel">
    <xsl:variable name="base">
      <xsl:value-of select="concat($outName,$ENCSUFF,'.html','#')"/>
    </xsl:variable>
    <HR/>
    <TABLE border="border" width="100%" summary="navigacija">
      <COLGROUP>
        <COL width="33%" valign="top" align="center"/>
        <COL width="33%" valign="top" align="center"/>
        <COL width="33%" valign="top" align="center"/>
      </COLGROUP>
      <!-- CROSS FONT -->
      <xsl:if test="self::div[@type='part'] or self::text or self::teiHeader or count(. | /) = 1">
        <TR>
          <TD align="left">
            <SMALL>
              <SPAN class="meta">
                <A>
                  <xsl:attribute name="href">
                    <xsl:call-template name="href">
                      <xsl:with-param name="ENCS">
                        <xsl:if test="string-length($ENCSUFF)=0">
                          <xsl:value-of select="$ENCSUFFIX"/>
                        </xsl:if>
                      </xsl:with-param>
                    </xsl:call-template>
                  </xsl:attribute>
                  <xsl:text>Prika&#x17E;i</xsl:text>
                </A>
                <xsl:text> </xsl:text>
                <xsl:choose>
                  <xsl:when test="$ENCODING = 'standard'">
                    <xsl:text>v pisavi </xsl:text>
                    <A href="{$ZRCOLA}">ZRCola</A>
                    <!--A>
                    <xsl:attribute name="href">
                      <xsl:call-template name="href">
                        <xsl:with-param name="id" select="$ZRCOLAID"/>
                      </xsl:call-template>
                    </xsl:attribute>
                    <xsl:text>ZRCola</xsl:text>
                  </A-->
                  </xsl:when>
                  <xsl:when test="$ENCODING = 'PUA'">
                    <xsl:text> v standardnem Unikodu</xsl:text>
                  </xsl:when>
                </xsl:choose>
              </SPAN>
            </SMALL>
          </TD>
          <TD align="center">
            <A href="{$base}bs">
              <SPAN class="meta">
                <xsl:copy-of select="$def-title"/>
              </SPAN>
            </A>
            <BR/>
            <A>
              <xsl:attribute name="href">
                <xsl:call-template name="href">
                  <xsl:with-param name="id" select="//teiHeader/@id"/>
                </xsl:call-template>
              </xsl:attribute>
              <SPAN class="meta">
                <xsl:value-of select="$teiHeader-desc-sl"/>
              </SPAN>
            </A>
          </TD>
          <TD align="right">
            <SMALL>
              <SPAN class="meta">
                  <xsl:text>Ta datoteka je zapisana v </xsl:text>
                  <xsl:choose>
                    <xsl:when test="$ENCODING = 'standard'">
                      <xsl:text>standardnem Unikodu</xsl:text>
                    </xsl:when>
                    <xsl:when test="$ENCODING = 'PUA'">
                      <xsl:text>pisavi </xsl:text>
                      <A href="{$ZRCOLA}">ZRCola</A>
                      <!--A>
                      <xsl:attribute name="href">
                      <xsl:call-template name="href">
                      <xsl:with-param name="id" select="$ZRCOLAID"/>
                      </xsl:call-template>
                      </xsl:attribute>
                      <xsl:text>ZRCola</xsl:text>
                      </A-->
                    </xsl:when>
                  </xsl:choose>
              </SPAN>
            </SMALL>
          </TD>
        </TR>
      </xsl:if>
      <TR>
        <!-- PREVIOUS -->
        <TD valign="top" align="center">
          <xsl:variable name="preceding">
            <xsl:choose>
              <xsl:when test="preceding-sibling::div[head]">
                <xsl:value-of select="preceding-sibling::div[head][1]/@id"/>
              </xsl:when>
              <xsl:when test="parent::div">
                <xsl:value-of select="parent::div/@id"/>
              </xsl:when>
            </xsl:choose>
          </xsl:variable>
          <xsl:choose>
            <xsl:when test="string-length($preceding)">
              <A>
                <xsl:attribute name="href">
                  <xsl:call-template name="href">
                    <xsl:with-param name="id" select="$preceding"/>
                  </xsl:call-template>
                </xsl:attribute>
                <SMALL>
                  <SPAN class="meta">
                    <xsl:value-of select="$nav-prev"/>
                  </SPAN>
                  <BR/>
                  <xsl:value-of select="id($preceding)/head[1]"/>
                </SMALL>
              </A>
            </xsl:when>
            <xsl:otherwise>
              <xsl:text>&#xA0;</xsl:text>
            </xsl:otherwise>
          </xsl:choose>
        </TD>
        <!-- TOC -->
        <TD valign="top" align="center">
          <SMALL>
            <A href="{$base}TOC-main">
              <SPAN class="meta">
                <xsl:value-of select="$toc-brief"/>
              </SPAN>
            </A>
            <BR/>
            <xsl:variable name="tocid">
              <xsl:if test="self::div[@id]">
                <xsl:value-of select="@id"/>
                <xsl:text>.</xsl:text>
              </xsl:if>
            </xsl:variable>
            <A href="{$base}{$tocid}TOC">
              <SPAN class="meta">
                <xsl:value-of select="$toc-full"/>
              </SPAN>
            </A>
            <BR/>
          </SMALL>
        </TD>
        <!-- NEXT -->
        <TD valign="top" align="center">
          <xsl:variable name="following">
            <xsl:choose>
              <xsl:when test="following-sibling::div">
                <xsl:value-of select="following-sibling::div[1]/@id"/>
              </xsl:when>
              <xsl:when test="parent::div/following-sibling::div">
                <xsl:value-of select="parent::div/following-sibling::div/@id"/>
              </xsl:when>
              <xsl:when test="ancestor::div[1]/following-sibling::div">
                <xsl:value-of select="parent::div/following-sibling::div/@id"/>
              </xsl:when>
              <xsl:when test="ancestor::div[2]/following-sibling::div">
                <xsl:value-of select="parent::div/following-sibling::div/@id"/>
              </xsl:when>
            </xsl:choose>
          </xsl:variable>
          <xsl:choose>
            <xsl:when test="string-length($following)">
              <A>
                <xsl:attribute name="href">
                  <xsl:call-template name="href">
                    <xsl:with-param name="id" select="$following"/>
                  </xsl:call-template>
                </xsl:attribute>
                <SMALL>
                  <SPAN class="meta">
                    <xsl:value-of select="$nav-next"/>
                  </SPAN>
                  <BR/>
                  <xsl:value-of select="id($following)/head[1]"/>
                </SMALL>
              </A>
            </xsl:when>
            <xsl:otherwise>
              <xsl:text>&#xA0;</xsl:text>
            </xsl:otherwise>
          </xsl:choose>
        </TD>
      </TR>
    </TABLE>
  </xsl:template>

  <xsl:template name="outputChunk">
    <xsl:param name="outFile" select="$outName"/>
    <xsl:param name="absFile" select="concat($outDir,$outFile,$ENCSUFF,'.html')"/>
    <xsl:param name="title">
      <xsl:value-of select="$id"/>
    </xsl:param>
    <xsl:param name="content"/>
    <xsl:choose>
      <xsl:when test="element-available('exsl:document')">
        <xsl:if test="$verbose='yes'">
          <xsl:message>Opening <xsl:value-of select="$absFile"/></xsl:message>
        </xsl:if>
        <exsl:document encoding="utf-8" method="html"
          doctype-public="-//W3C//DTD HTML 4.01 Transitional//EN" href="{$absFile}">
          <HTML>
            <xsl:comment>THIS FILE IS GENERATED FROM AN XML MASTER. DO NOT EDIT!</xsl:comment>
            <HEAD>
              <META name="generator" content="{$VERSION}"/>
              <TITLE>
                <xsl:value-of select="normalize-space($title)"/>
              </TITLE>
              <META http-equiv="Content-Type" content="text/html; charset=utf-8"/>
              <STYLE TYPE="text/css">
                <xsl:value-of select="$css_style"/>
              </STYLE>
            </HEAD>
            <BODY>
              <!--
            <xsl:if test="not(debug)">
              <xsl:attribute name="background">
                <xsl:value-of select="background"/>
              </xsl:attribute>
            </xsl:if>
            -->
              <xsl:copy-of select="$content"/>
              <xsl:copy-of select="$html-footer"/>
            </BODY>
          </HTML>
        </exsl:document>
        <xsl:if test="$verbose='yes'">
          <xsl:message>Closing <xsl:value-of select="$absFile"/></xsl:message>
        </xsl:if>
      </xsl:when>
      <xsl:otherwise>
        <xsl:if test="$verbose='yes'">
          <xsl:message>Creation of <xsl:value-of select="$absFile"/> not possible</xsl:message>
        </xsl:if>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="page-text">
    <xsl:choose>
      <xsl:when test=".//milestone[@unit='column']">
        <TR>
          <TD valign="middle">
            <TABLE summary="besedilo faksimila">
              <xsl:for-each select="line[following-sibling::milestone[@unit='column']]">
                <xsl:call-template name="line"/>
              </xsl:for-each>
            </TABLE>
          </TD>
          <TD valign="middle">
            <TABLE summary="besedilo faksimila">
              <xsl:for-each select="line[preceding-sibling::milestone[@unit='column']]">
                <xsl:call-template name="line"/>
              </xsl:for-each>
            </TABLE>
          </TD>
        </TR>
      </xsl:when>
      <xsl:otherwise>
        <xsl:for-each select="line">
          <xsl:call-template name="line"/>
        </xsl:for-each>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="line">
    <TR>
      <TD align="right" valign="middle">
        <xsl:call-template name="anchor"/>
        <xsl:if test="(@n mod 5) = 0 or starts-with(@id,'bsPA')">
          <SPAN class="meta">
            <xsl:value-of select="@n"/>
          </SPAN>
        </xsl:if>
        <!--output page line number with DIPL transcriptions -->
        <xsl:if test="starts-with(@id,'bsDT')">
          <xsl:variable name="pos">
            <xsl:number count="line" from="page"/>
          </xsl:variable>
          <xsl:if test="$pos = 1 or ($pos mod 5) = 0">
            <SPAN class="meta">
              <SUB>
                <xsl:value-of select="$pos"/>
              </SUB>
            </SPAN>
          </xsl:if>
        </xsl:if>
      </TD>
      <TD>
        <xsl:choose>
          <xsl:when test="@select">
            <TABLE border="border" rules="rows" width="100%" summary="vrstica">
              <xsl:for-each select="id(@select)">
                <TR>
                  <TD>
                    <xsl:apply-templates select=".">
                      <xsl:with-param name="para">yes</xsl:with-param>
                    </xsl:apply-templates>
                  </TD>
                  <TD align="right">
                    <A>
                      <xsl:attribute name="href">
                        <xsl:call-template name="href"/>
                      </xsl:attribute>
                      <SMALL>
                        <xsl:choose>
                          <xsl:when test="$debug">
                            <xsl:value-of select="@id"/>
                          </xsl:when>
                          <xsl:otherwise>
                            <xsl:value-of mode="toc" select="ancestor::div[@type='section']/head[1]"
                            />
                          </xsl:otherwise>
                        </xsl:choose>
                      </SMALL>
                    </A>
                  </TD>
                </TR>
              </xsl:for-each>
            </TABLE>
          </xsl:when>
          <xsl:otherwise>
            <xsl:apply-templates select="."/>
          </xsl:otherwise>
        </xsl:choose>
      </TD>
    </TR>
  </xsl:template>

  <xsl:template name="concord">
    <xsl:param name="len">40</xsl:param>
    <xsl:variable name="lc">
      <xsl:value-of select="preceding-sibling::text()"/>
    </xsl:variable>
    <xsl:variable name="rc">
      <xsl:value-of select="following-sibling::text()"/>
    </xsl:variable>
    <xsl:variable name="text">
      <xsl:value-of select="substring(..,1,$len)"/>
      <!--
    <xsl:text>&#x2026;</xsl:text>
    <xsl:value-of select="substring($lc,(string-length($lc)-$len),$len)"/>
    <xsl:text> &lt;</xsl:text>
    <xsl:value-of select="."/>
    <xsl:text>&gt; </xsl:text>
    <xsl:value-of select="substring($rc,1,$len)"/>
    <xsl:value-of select="$rc"/>
    <xsl:text>&#x2026;</xsl:text>
    -->
    </xsl:variable>
    <xsl:value-of select="normalize-space(translate($text,'&#10;',' '))"/>
  </xsl:template>

  <xsl:template name="anchor">
    <xsl:param name="suffix"/>
    <xsl:param name="id">
      <xsl:choose>
        <xsl:when test="@id">
          <xsl:value-of select="@id"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="generate-id(.)"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:param>
    <A>
      <xsl:attribute name="name">
        <xsl:value-of select="$id"/>
        <xsl:value-of select="$suffix"/>
      </xsl:attribute>
    </A>
  </xsl:template>

  <xsl:template name="href">
    <xsl:param name="ENCS" select="$ENCSUFF"/>
    <xsl:param name="suffix"/>
    <xsl:param name="id">
      <xsl:choose>
        <xsl:when test="@id">
          <xsl:value-of select="@id"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="generate-id(.)"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:param>
    <xsl:variable name="fileid">
      <xsl:choose>
        <xsl:when test="id($id)[name()='teiHeader']">
          <xsl:value-of select="$id"/>
        </xsl:when>
        <xsl:when test="id($id)/ancestor-or-self::div[@type='part']">
          <xsl:value-of select="id($id)/ancestor-or-self::div[@type='part']/@id"/>
        </xsl:when>
        <xsl:when test="ancestor-or-self::div[@type='part']">
          <xsl:value-of select="ancestor-or-self::div[@type='part']/@id"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="$outName"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <xsl:if test="$split">
      <xsl:value-of select="$fileid"/>
      <xsl:value-of select="$ENCS"/>
      <xsl:text>.html</xsl:text>
    </xsl:if>
    <xsl:if test="not($split and $fileid=$id)">
      <xsl:text>#</xsl:text>
      <xsl:choose>
        <xsl:when test="id($id)/@id">
          <xsl:value-of select="id($id)/@id"/>
        </xsl:when>
        <xsl:when test="@id">
          <xsl:value-of select="@id"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="$id"/>
        </xsl:otherwise>
      </xsl:choose>
      <xsl:value-of select="$suffix"/>
    </xsl:if>
  </xsl:template>

  <!-- Mark sound milestone with odd or even color -->
  <xsl:template name="color-mark">
    <xsl:variable name="odd"
      select="(
            count(preceding-sibling::milestone[@unit='sentence'])+
            count(../preceding-sibling::line//milestone[@unit='sentence'])+
            count(ancestor::page/preceding-sibling::page/line//milestone[@unit='sentence'])
            ) mod 2"/>
    <xsl:attribute name="class">
      <xsl:choose>
        <xsl:when test="$odd">evenmark</xsl:when>
        <xsl:otherwise>oddmark</xsl:otherwise>
      </xsl:choose>
    </xsl:attribute>
    <xsl:if test="$debug">
      <xsl:text>[</xsl:text>
      <xsl:value-of select="count(preceding-sibling::milestone[@unit='sentence'])"/>
      <xsl:text>+</xsl:text>
      <xsl:value-of select="count(../preceding-sibling::line//milestone[@unit='sentence'])"/>
      <xsl:text>+</xsl:text>
      <xsl:value-of
        select="count(ancestor::page/preceding-sibling::page/line//milestone[@unit='sentence'])"/>
      <xsl:text>]</xsl:text>
    </xsl:if>
  </xsl:template>

  <xsl:template name="color-sent">
    <xsl:variable name="odd"
      select="( 
            count(preceding-sibling::milestone[@unit='sentence'])+
            count(../preceding-sibling::line//milestone[@unit='sentence'])+
            count(ancestor::page/preceding-sibling::page/line//milestone[@unit='sentence'])
            ) mod 2"/>
    <xsl:text disable-output-escaping="yes">&lt;/SPAN&gt;</xsl:text>
    <xsl:text disable-output-escaping="yes">&lt;SPAN class=&quot;</xsl:text>
    <xsl:choose>
      <xsl:when test="$odd">oddsent</xsl:when>
      <xsl:otherwise>evensent</xsl:otherwise>
    </xsl:choose>
    <xsl:text disable-output-escaping="yes">&quot;&gt;</xsl:text>
    <xsl:if test="$debug">
      <xsl:text>[</xsl:text>
      <xsl:value-of select="count(preceding-sibling::milestone[@unit='sentence'])"/>
      <xsl:text>+</xsl:text>
      <xsl:value-of select="count(../preceding-sibling::line//milestone[@unit='sentence'])"/>
      <xsl:text>+</xsl:text>
      <xsl:value-of
        select="count(ancestor::page/preceding-sibling::page/line//milestone[@unit='sentence'])"/>
      <xsl:text>]</xsl:text>
    </xsl:if>
  </xsl:template>

  <xsl:template name="color-line">
    <xsl:variable name="odd"
      select="( 
            count(preceding-sibling::line/milestone[@unit='sentence'])+
            count(ancestor::page/preceding-sibling::page/line/milestone[@unit='sentence'])
            ) mod 2"/>
    <xsl:choose>
      <xsl:when test="$odd">evensent</xsl:when>
      <xsl:otherwise>oddsent</xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template mode="footer" match="p">
    <SPAN class="meta">
      <xsl:apply-templates/>
      <xsl:if test="following-sibling::p">; </xsl:if>
    </SPAN>
  </xsl:template>

</xsl:stylesheet>
