<?xml version='1.0'?>
<!-- TEI Header -> HTML                                                     -->
<!-- 2007-01-29                                                             -->
<!-- Tomaz Erjavec                                                          -->
<!--                                                                        -->

<xsl:stylesheet version='1.0' 
     xmlns:xsl="http://www.w3.org/1999/XSL/Transform" >

<xsl:param name="tei-url">http://www.tei-c.org.uk/P4X/</xsl:param>
<!--xsl:param name="tei-url">TEI_P4/</xsl:param-->
<xsl:param name="lang">sl</xsl:param>

<xsl:output
  method = "html"
  encoding = "utf-8"
  omit-xml-declaration = "yes"
  indent = "yes"/> 

<xsl:strip-space elements="xptr"/>

<!-- stub, used probably only when using this file directly to display header only -->
<xsl:template match="/">
   <HTML>
     <HEAD>
       <TITLE>
         <xsl:value-of select="$LABEL-teiHeader"/>
         <xsl:text>: </xsl:text>
         <xsl:value-of select="//fileDesc/titleStmt/title"/>
         (<xsl:value-of select="//teiHeader/@date.updated"/>)
       </TITLE>
       <META HTTP-EQUIV="Content-Type" CONTENT="text/html; charset=utf-8"/>
     </HEAD>
     <BODY>
       <H1 align="center">
         <xsl:value-of select="//teiHeader/fileDesc/titleStmt/title"/>
         <BR/>
         <xsl:value-of select="$LABEL-edition"/>
         <xsl:value-of select="//editionStmt/edition"/>
       </H1>
       <xsl:apply-templates select="//teiHeader"/>
     </BODY>
  </HTML>
</xsl:template>

<xsl:template match="teiHeader">
  <xsl:call-template name="navpanel"/>
  <H1 align="left">
    <A NAME="{@id}"/>
    <xsl:copy-of select="$LABEL-teiHeader"/>
  </H1>
  <TABLE summary="TEI header">
    <xsl:if test="not(@type = 'text')">
      <TR>
        <TH align="left">
          <xsl:value-of select="$LABELATT-type"/>
          <xsl:text>:</xsl:text>
        </TH>
        <TD><xsl:value-of select="@type"/></TD>
      </TR>
    </xsl:if>
    <xsl:if test="@lang">
      <TR>
        <TH align="left">
          <xsl:value-of select="$LABELATT-lang"/>
          <xsl:text>:</xsl:text>
        </TH>
        <TD><xsl:value-of select="id(@lang)"/></TD>
      </TR>
    </xsl:if>
    <xsl:if test="@creator">
      <TR>
        <TH align="left">
          <xsl:value-of select="$LABELATT-creator"/>
          <xsl:text>:</xsl:text>
        </TH>
        <TD><xsl:value-of select="@creator"/></TD>
      </TR>
    </xsl:if>
    <xsl:if test="@date.created or @date.updated">
      <TR>
        <TH align="left">
          <xsl:value-of select="$LABELATT-date"/>
          <xsl:text>:</xsl:text>
        </TH>
        <xsl:if test="@date.created">
          <TD>
            <xsl:value-of select="@date.created"/>
            <xsl:text> (</xsl:text>
            <xsl:value-of select="$LABELATT-date.created"/>
            <xsl:text>) </xsl:text>
          </TD>
        </xsl:if>
        <xsl:if test="@date.updated">
          <TD>
            <xsl:value-of select="@date.updated"/>
            <xsl:text> (</xsl:text>
            <xsl:value-of select="$LABELATT-date.updated"/>
            <xsl:text>) </xsl:text>
          </TD>
        </xsl:if>
      </TR>
    </xsl:if>
  </TABLE>
  <xsl:apply-templates/>
  <xsl:call-template name="navpanel"/>
</xsl:template>

<xsl:template match="fileDesc">
  <xsl:call-template name="h2-dl">
    <xsl:with-param name="name">fileDesc</xsl:with-param>
    <xsl:with-param name="label" select="$LABEL-fileDesc"/>
  </xsl:call-template>
</xsl:template>

<xsl:template match="encodingDesc">
  <xsl:call-template name="h2-dl">
    <xsl:with-param name="name">encodingDesc</xsl:with-param>
    <xsl:with-param name="label" select="$LABEL-encodingDesc"/>
  </xsl:call-template>
</xsl:template>

<xsl:template match="profileDesc">
  <xsl:call-template name="h2-dl">
    <xsl:with-param name="name">profileDesc</xsl:with-param>
    <xsl:with-param name="label" select="$LABEL-profileDesc"/>
  </xsl:call-template>
</xsl:template>

<xsl:template match="revisionDesc">
  <xsl:call-template name="h2-ul">
    <xsl:with-param name="name">revisionDesc</xsl:with-param>
    <xsl:with-param name="label" select="$LABEL-revisionDesc"/>
  </xsl:call-template>
</xsl:template>

<xsl:template match="sourceDesc">
  <xsl:call-template name="dt-dl">
    <xsl:with-param name="label" select="$LABEL-sourceDesc"/>
  </xsl:call-template>
</xsl:template>

<xsl:template match="projectDesc">
  <xsl:call-template name="dt-dl">
    <xsl:with-param name="label" select="$LABEL-projectDesc"/>
  </xsl:call-template>
</xsl:template>

<xsl:template match="titleStmt">
  <xsl:call-template name="dt-dl">
    <xsl:with-param name="label" select="$LABEL-titleStmt"/>
  </xsl:call-template>
</xsl:template>

<xsl:template match="principal">
  <xsl:call-template name="dt-dl">
    <xsl:with-param name="label" select="$LABEL-principal"/>
  </xsl:call-template>
</xsl:template>

<xsl:template match="publicationStmt">
  <xsl:call-template name="dt-dl">
    <xsl:with-param name="label" select="$LABEL-publicationStmt"/>
  </xsl:call-template>
</xsl:template>

<xsl:template match="notesStmt">
  <xsl:call-template name="dt-dl">
    <xsl:with-param name="label" select="$LABEL-notesStmt"/>
  </xsl:call-template>
</xsl:template>

<xsl:template match="teiHeader//respStmt">
  <xsl:call-template name="dt-dl">
    <xsl:with-param name="label" select="$LABEL-respStmt"/>
  </xsl:call-template>
</xsl:template>
<xsl:template match="change/respStmt">
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="editionStmt[p]">
  <xsl:call-template name="dt-dd">
    <xsl:with-param name="label" select="$LABEL-editionStmt"/>
  </xsl:call-template>
</xsl:template>
<xsl:template match="editionStmt">
  <xsl:call-template name="dt-dl">
    <xsl:with-param name="label" select="$LABEL-editionStmt"/>
  </xsl:call-template>
</xsl:template>

<xsl:template match="editorialDecl">
  <xsl:call-template name="dt-dl">
    <xsl:with-param name="label" select="$LABEL-editorialDecl"/>
  </xsl:call-template>
</xsl:template>

<xsl:template match="tagsDecl">
  <xsl:call-template name="dt-dl">
    <xsl:with-param name="label" select="$LABEL-tagsDecl"/>
  </xsl:call-template>
</xsl:template>

<!-- USER EXTENSION -->
<xsl:template match="charDesc">
  <DT>
    <B>
      <xsl:copy-of select="$LABEL-charDesc"/>
    </B>
    <xsl:text>:</xsl:text>
  </DT>
  <DD>
    <xsl:apply-templates select="desc"/>
  </DD>
  <DD>
    <DL>
      <xsl:for-each select="char">
        <DT><xsl:value-of select="charName"/> (<xsl:value-of select="@id"/>)</DT>
        <xsl:for-each select="charProp">
          <DD>
            <xsl:value-of select="localName"/>=<xsl:value-of select="value"/>
          </DD>
        </xsl:for-each>
        <xsl:for-each select="mapping">
          <DD><xsl:value-of select="@type"/> = <BIG>[<xsl:value-of select="."/>]</BIG></DD>
        </xsl:for-each>
      </xsl:for-each>
    </DL>
  </DD>
</xsl:template>

<xsl:template match="classDecl">
  <xsl:call-template name="dt-dl">
    <xsl:with-param name="label" select="$LABEL-classDecl"/>
  </xsl:call-template>
</xsl:template>

<xsl:template match="fsdDecl">
  <xsl:call-template name="dt-dl">
    <xsl:with-param name="label" select="$LABEL-fsdDecl"/>
  </xsl:call-template>
</xsl:template>

<xsl:template match="teiHeader//fLib">
  <DT>
    <xsl:copy-of select="$LABEL-flib"/>
  </DT>
  <xsl:if test="@type">
    <DD>
      <xsl:value-of select="@type"/>
    </DD>
  </xsl:if>
</xsl:template>

<xsl:template match="teiHeader//fsLib">
  <DT>
    <xsl:copy-of select="$LABEL-fslib"/>
  </DT>
  <xsl:if test="@type">
    <DD>
      <xsl:value-of select="@type"/>
    </DD>
  </xsl:if>
</xsl:template>

<xsl:template match="taxonomy">
  <xsl:call-template name="dt-dl">
    <xsl:with-param name="label" select="$LABEL-taxonomy"/>
  </xsl:call-template>
</xsl:template>

<xsl:template match="category">
  <xsl:call-template name="dt-dl">
    <xsl:with-param name="label">
      <xsl:copy-of select="$LABEL-category"/>
      <xsl:if test="@id">
        <xsl:text> "</xsl:text>
        <xsl:value-of select="@id"/>
        <xsl:text>"</xsl:text>
      </xsl:if>
    </xsl:with-param>
  </xsl:call-template>
</xsl:template>

<xsl:template match="catDesc">
  <DT>
    <xsl:apply-templates/>
  </DT>
</xsl:template>

<xsl:template match="correction">
  <xsl:call-template name="dt-dd">
    <xsl:with-param name="label" select="$LABEL-correction"/>
  </xsl:call-template>
</xsl:template>

<xsl:template match="hyphenation">
  <xsl:call-template name="dt-dd">
    <xsl:with-param name="label" select="$LABEL-hyphenation"/>
  </xsl:call-template>
</xsl:template>

<xsl:template match="normalization">
  <xsl:call-template name="dt-dd">
    <xsl:with-param name="label" select="$LABEL-normalization"/>
  </xsl:call-template>
</xsl:template>

<xsl:template match="quotation">
  <xsl:call-template name="dt-dd">
    <xsl:with-param name="label" select="$LABEL-quotation"/>
  </xsl:call-template>
</xsl:template>

<xsl:template match="segmentation">
  <xsl:call-template name="dt-dd">
    <xsl:with-param name="label" select="$LABEL-segmentation"/>
  </xsl:call-template>
</xsl:template>

<xsl:template match="interpretation">
  <xsl:call-template name="dt-dd">
    <xsl:with-param name="label" select="$LABEL-interpretation"/>
  </xsl:call-template>
</xsl:template>

<xsl:template match="stdVals">
  <xsl:call-template name="dt-dd">
    <xsl:with-param name="label" select="$LABEL-stdVals"/>
  </xsl:call-template>
</xsl:template>

<!--
  <xsl:choose>
    <xsl:when test="false()">
    </xsl:when>
    <xsl:otherwise>
    </xsl:otherwise>
  </xsl:choose>
-->

<xsl:template match="teiHeader//address">
  <xsl:call-template name="dt-dd">
    <xsl:with-param name="label" select="$LABEL-address"/>
  </xsl:call-template>
</xsl:template>

<xsl:template match="teiHeader//availability">
  <xsl:call-template name="dt-dd">
    <xsl:with-param name="label">
      <xsl:copy-of select="$LABEL-availability"/>
      <!--xsl:if test="@status">  not for BS!
        <xsl:text> (</xsl:text>
        <xsl:value-of select="@status"/>
        <xsl:text>) </xsl:text>
      </xsl:if-->
    </xsl:with-param>
  </xsl:call-template>
</xsl:template>

<xsl:template match="teiHeader//idno">
  <xsl:call-template name="dt-dd">
    <xsl:with-param name="label">
      <xsl:copy-of select="$LABEL-idno"/>
    </xsl:with-param>
  </xsl:call-template>
</xsl:template>

<xsl:template match="teiHeader//xref">
  <xsl:choose>
    <xsl:when test="@url and (@from = 'ROOT')">
       <A href="{@url}"><xsl:apply-templates/></A>
    </xsl:when>
    <xsl:when test="@url">
       <A href="{@url}#{@from}"><xsl:apply-templates/></A>
    </xsl:when>
    <xsl:otherwise>
        Arrgfh! Argh!!
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="teiHeader//xptr">
  <xsl:text>&lt;</xsl:text>
  <xsl:choose>
    <xsl:when test="@url and (@from = 'ROOT')">
       <A href="{@url}">
         <xsl:value-of select="@url"/>
       </A>
    </xsl:when>
    <xsl:when test="@url">
       <A href="{@url}#{@from}">
         <xsl:value-of select="@url"/>#<xsl:value-of select="@from"/>
       </A>
    </xsl:when>
    <xsl:otherwise>
        Arrgfh! Argh!!
    </xsl:otherwise>
  </xsl:choose>
  <xsl:text>&gt;</xsl:text>
</xsl:template>

<xsl:template match="extent">
  <xsl:call-template name="dt-dd">
    <xsl:with-param name="label" select="$LABEL-extent"/>
  </xsl:call-template>
</xsl:template>

<xsl:template match="teiHeader//imprint">
  <xsl:call-template name="dt-dl">
    <xsl:with-param name="label" select="$LABEL-imprint"/>
  </xsl:call-template>
</xsl:template>

<xsl:template match="teiHeader//distributor">
  <xsl:call-template name="dt-dd">
    <xsl:with-param name="label" select="$LABEL-distributor"/>
  </xsl:call-template>
</xsl:template>

<xsl:template match="teiHeader//pubPlace">
  <xsl:choose>
    <xsl:when test="parent::bibl">
      <xsl:apply-templates/>
      <xsl:text> </xsl:text>
    </xsl:when>
    <xsl:otherwise>
      <xsl:call-template name="dt-dd">
        <xsl:with-param name="label" select="$LABEL-pubPlace"/>
      </xsl:call-template>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="teiHeader//publisher">
  <xsl:choose>
    <xsl:when test="parent::bibl">
      <xsl:apply-templates/>
      <xsl:text> </xsl:text>
    </xsl:when>
    <xsl:when test="*">
      <xsl:call-template name="dt-dl">
        <xsl:with-param name="label" select="$LABEL-publisher"/>
      </xsl:call-template>
    </xsl:when>
    <xsl:otherwise>
      <xsl:call-template name="dt-dd">
        <xsl:with-param name="label" select="$LABEL-publisher"/>
      </xsl:call-template>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="teiHeader//title">
  <xsl:choose>
    <xsl:when test="parent::bibl">
      <EM><xsl:apply-templates/></EM>
      <xsl:text> </xsl:text>
    </xsl:when>
    <xsl:otherwise>
      <xsl:call-template name="dt-dd">
        <xsl:with-param name="label" select="$LABEL-title"/>
      </xsl:call-template>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="langUsage">
  <xsl:call-template name="dt-dd">
    <xsl:with-param name="label" select="$LABEL-langUsage"/>
  </xsl:call-template>
</xsl:template>

<xsl:template match="handList">
  <xsl:call-template name="dt-ul">
    <xsl:with-param name="label" select="$LABEL-handList"/>
  </xsl:call-template>
</xsl:template>

<xsl:template match="hand">
  <LI>
    <B>
      <xsl:value-of select="@id"/>
    </B>
    <xsl:text> = </xsl:text>
    <xsl:value-of select="@scribe"/>
  </LI>
</xsl:template>

<xsl:template match="teiHeader//listBibl">
  <xsl:choose>
    <xsl:when test="../sourceDesc">
      <xsl:call-template name="dt-ul">
        <xsl:with-param name="label" select="$LABEL-listBibl"/>
      </xsl:call-template>
    </xsl:when>
    <xsl:otherwise>
      <UL>
        <xsl:apply-templates/>
      </UL>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="tagUsage">
  <DT>
    <B>
      <A>
        <xsl:attribute name="href">
          <xsl:call-template name="teip4-elts">
            <xsl:with-param name="gi" select="@gi"/>
          </xsl:call-template>
        </xsl:attribute>
        <xsl:value-of select="@gi"/>
      </A>
    </B> 
    <xsl:text> = </xsl:text>
    <xsl:value-of select="@occurs"/>
  </DT>
  <xsl:if test=".">
    <DD>
      <xsl:apply-templates/>
    </DD>
  </xsl:if>
</xsl:template>

<xsl:template match="teiHeader//addrLine">
  <xsl:apply-templates/>
  <BR/>
</xsl:template>

<xsl:template match="teiHeader//author">
  <xsl:choose>
    <xsl:when test="ancestor::titleStmt">
      <xsl:call-template name="dt-dl">
        <xsl:with-param name="label" select="$LABEL-author"/>
      </xsl:call-template>
    </xsl:when>
    <xsl:otherwise>
      <xsl:apply-templates/>
      <xsl:text> </xsl:text>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="titleStmt//editor">
  <xsl:call-template name="dt-dd">
    <xsl:with-param name="label" select="$LABEL-titleStmt-editor"/>
  </xsl:call-template>
</xsl:template>

<xsl:template match="teiHeader//editor">
  <xsl:apply-templates/>
  <xsl:text> </xsl:text>
  <xsl:copy-of select="$LABEL-editor"/>
  <xsl:text> </xsl:text>
</xsl:template>

<xsl:template match="change">
  <LI>
    <xsl:apply-templates/>
  </LI>
</xsl:template>

<xsl:template match="teiHeader//resp">
  <xsl:choose>
    <xsl:when test="ancestor::revisionDesc">
      <xsl:text> (</xsl:text> 
      <xsl:apply-templates/>
      <xsl:text>) </xsl:text> 
    </xsl:when>
    <xsl:when test="ancestor::principal">
      <DT>
        <xsl:apply-templates/>
      </DT>
    </xsl:when>
    <xsl:otherwise>
      <DT>
        <xsl:apply-templates/>
        <xsl:if test="following-sibling::*[1][name]">
          <xsl:text>: </xsl:text>
        </xsl:if>
      </DT>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="teiHeader//name">
  <xsl:choose>
    <xsl:when test="ancestor::titleStmt or ancestor::editionStmt">
      <DD>
        <xsl:apply-templates/>
      </DD>
    </xsl:when>
    <xsl:otherwise>
      <xsl:apply-templates/>
      <xsl:if test="following-sibling::name">, </xsl:if>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="teiHeader//edition">
  <xsl:choose>
    <xsl:when test="parent::*">   <!-- we want this everywhere -->
      <xsl:call-template name="dt-dd">
        <xsl:with-param name="label" select="$LABEL-edition"/>
      </xsl:call-template>
    </xsl:when>
    <xsl:otherwise>
      <BR/>
      <B>
        <xsl:copy-of select="$LABEL-edition"/>
      </B>
      <xsl:text>: </xsl:text> 
      <xsl:apply-templates/>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="teiHeader//bibl">
  <xsl:choose>
    <xsl:when test="ancestor::listBibl">
      <LI><xsl:apply-templates/></LI>
    </xsl:when>
    <xsl:otherwise>
      <xsl:call-template name="dt-dl">
        <xsl:with-param name="label" select="$LABEL-bibl"/>
      </xsl:call-template>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="teiHeader//monogr">
  <xsl:call-template name="dt-dl">
    <xsl:with-param name="label" select="$LABEL-monogr"/>
  </xsl:call-template>
</xsl:template>
<xsl:template match="teiHeader//analytic">
  <xsl:call-template name="dt-dl">
    <xsl:with-param name="label" select="$LABEL-analytic"/>
  </xsl:call-template>
</xsl:template>

<xsl:template match="teiHeader//date">
  <xsl:choose>
    <xsl:when test="parent::publicationStmt or parent::imprint">
      <xsl:call-template name="dt-dd">
        <xsl:with-param name="label" select="$LABEL-date"/>
      </xsl:call-template>
    </xsl:when>
    <xsl:otherwise>
      <EM>
        <xsl:apply-templates/>
      </EM> 
      <xsl:text> </xsl:text>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="teiHeader//foreign">
  <I>
    <xsl:apply-templates/>
  </I>
</xsl:template>

<xsl:template match="teiHeader//language">
  <A NAME="{@id}">
    <B>
      <xsl:value-of select="@id"/>
    </B>
  </A>
  <xsl:text> = </xsl:text>
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="teiHeader//p">
  <xsl:choose>
    <xsl:when test="parent::profileDesc or parent::projectDesc or parent::revisionDesc or parent::sourceDesc">
      <DD>
        <xsl:apply-templates/>
      </DD>
    </xsl:when>
    <xsl:otherwise>
      <P>
        <xsl:apply-templates/>
      </P>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="teiHeader//list">
  <xsl:choose>
    <xsl:when test="parent::revisionDesc">
      <xsl:apply-templates/>
    </xsl:when>
    <xsl:otherwise>
      <UL>
        <xsl:apply-templates/>
      </UL>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="teiHeader//item">
  <xsl:choose>
    <xsl:when test="parent::change">
      <BR/>
      <xsl:apply-templates/>
    </xsl:when>
    <xsl:otherwise>
      <LI>
        <xsl:apply-templates/>
      </LI>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="teiHeader//note">
  <DT>
    <B>
      <xsl:copy-of select="$LABEL-note"/>
    </B>
    <xsl:if test="@type">
      <xsl:text> (</xsl:text>
      <xsl:value-of select="@type"/>
      <xsl:text>)</xsl:text>
    </xsl:if>
    <xsl:text>:</xsl:text>
  </DT>
  <DD>
    <xsl:apply-templates/>
  </DD>
</xsl:template>

<xsl:template match="teiHeader//q">
  <xsl:text>"</xsl:text>
  <xsl:apply-templates/>
  <xsl:text>"</xsl:text>
</xsl:template>

<xsl:template match="teiHeader//term">
  <I>
    <xsl:apply-templates/>
  </I>
</xsl:template>

<xsl:template match="teiHeader//seg">
  <xsl:apply-templates/>
  <xsl:if test="@lang">
    <xsl:text> (</xsl:text>
    <xsl:value-of select="id(@lang)"/>
    <xsl:text>) </xsl:text>
  </xsl:if>
  <BR/>
</xsl:template>

<xsl:template match="teiHeader//lb">
  <BR/>
</xsl:template>

<xsl:template name="h2-dl">
  <xsl:param name="name"/>
  <xsl:param name="label">???</xsl:param>
  <H2>
    <A NAME="{$name}"/>
    <xsl:copy-of select="$label"/>
  </H2>
  <DL>
    <xsl:apply-templates/>
  </DL>
</xsl:template>

<xsl:template name="h2-ul">
  <xsl:param name="name"/>
  <xsl:param name="label">???</xsl:param>
  <H2>
    <A NAME="{$name}"/>
    <xsl:copy-of select="$label"/>
  </H2>
  <UL>
    <xsl:apply-templates/>
  </UL>
</xsl:template>

<xsl:template name="h3-dl">
  <xsl:param name="label">???</xsl:param>
  <H3>
    <xsl:copy-of select="$label"/>
  </H3>
  <DL>
    <xsl:apply-templates/>
  </DL>
</xsl:template>

<xsl:template name="dt-dd">
  <xsl:param name="label">???</xsl:param>
  <DT>
    <B>
      <xsl:copy-of select="$label"/>
    </B>
    <xsl:text>:</xsl:text>
  </DT>
  <DD>
    <xsl:apply-templates/>
  </DD>
</xsl:template>

<xsl:template name="dt-dl">
  <xsl:param name="label">???</xsl:param>
  <DT>
    <B>
      <xsl:copy-of select="$label"/>
    </B>
    <xsl:text>:</xsl:text>
  </DT>
  <DD>
    <DL><xsl:apply-templates/></DL>
  </DD>
</xsl:template>

<xsl:template name="dt-ul">
  <xsl:param name="label">???</xsl:param>
  <DT>
    <B>
      <xsl:copy-of select="$label"/>
    </B>
    <xsl:text>:</xsl:text>
  </DT>
  <DD>
    <UL><xsl:apply-templates/></UL>
  </DD>
</xsl:template>

<xsl:template name="teip4-elts">
  <xsl:param name="gi"/>
  <xsl:value-of select="$tei-url"/>
  <!-- TEI P4 Chp.35: Elements -->
  <xsl:choose>
    <xsl:when test="$gi='abbr'">ref-ABBR.html</xsl:when>
    <xsl:when test="$gi='activity'">ref-ACTIVITY.html</xsl:when>
    <xsl:when test="$gi='actor'">ref-ACTOR.html</xsl:when>
    <xsl:when test="$gi='add'">ref-ADD.html</xsl:when>
    <xsl:when test="$gi='addName'">ref-ADDNAME.html</xsl:when>
    <xsl:when test="$gi='address'">ref-ADDRESS.html</xsl:when>
    <xsl:when test="$gi='addrLine'">ref-ADDRLINE.html</xsl:when>
    <xsl:when test="$gi='addSpan'">ref-ADDSPAN.html</xsl:when>
    <xsl:when test="$gi='admin'">ref-ADMIN.html</xsl:when>
    <xsl:when test="$gi='affiliation'">ref-AFFILIAT.html</xsl:when>
    <xsl:when test="$gi='alt'">ref-ALT.html</xsl:when>
    <xsl:when test="$gi='altGrp'">ref-ALTGRP.html</xsl:when>
    <xsl:when test="$gi='analytic'">ref-ANALYTIC.html</xsl:when>
    <xsl:when test="$gi='anchor'">ref-ANCHOR.html</xsl:when>
    <xsl:when test="$gi='ab'">ref-ANONB.html</xsl:when>
    <xsl:when test="$gi='any'">ref-ANY.html</xsl:when>
    <xsl:when test="$gi='app'">ref-APP.html</xsl:when>
    <xsl:when test="$gi='arc'">ref-ARC.html</xsl:when>
    <xsl:when test="$gi='argument'">ref-ARGUMENT.html</xsl:when>
    <xsl:when test="$gi='att'">ref-ATT.html</xsl:when>
    <xsl:when test="$gi='attDef'">ref-ATTDEF.html</xsl:when>
    <xsl:when test="$gi='attlDecl'">ref-ATTLDECL.html</xsl:when>
    <xsl:when test="$gi='attList'">ref-ATTLIST.html</xsl:when>
    <xsl:when test="$gi='attName'">ref-ATTNAME.html</xsl:when>
    <xsl:when test="$gi='author'">ref-AUTHOR.html</xsl:when>
    <xsl:when test="$gi='authority'">ref-AUTHORTY.html</xsl:when>
    <xsl:when test="$gi='availability'">ref-AVAIL.html</xsl:when>
    <xsl:when test="$gi='back'">ref-BACK.html</xsl:when>
    <xsl:when test="$gi='baseWsd'">ref-BASEWSD.html</xsl:when>
    <xsl:when test="$gi='bibl'">ref-BIBL.html</xsl:when>
    <xsl:when test="$gi='biblFull'">ref-BIBLFULL.html</xsl:when>
    <xsl:when test="$gi='biblScope'">ref-BIBLSCOP.html</xsl:when>
    <xsl:when test="$gi='biblStruct'">ref-BIBLSTRU.html</xsl:when>
    <xsl:when test="$gi='bicond'">ref-BICOND.html</xsl:when>
    <xsl:when test="$gi='birth'">ref-BIRTH.html</xsl:when>
    <xsl:when test="$gi='bloc'">ref-BLOC.html</xsl:when>
    <xsl:when test="$gi='body'">ref-BODY.html</xsl:when>
    <xsl:when test="$gi='broadcast'">ref-BROADCAS.html</xsl:when>
    <xsl:when test="$gi='byline'">ref-BYLINE.html</xsl:when>
    <xsl:when test="$gi='c'">ref-C.html</xsl:when>
    <xsl:when test="$gi='caesura'">ref-CAESURA.html</xsl:when>
    <xsl:when test="$gi='camera'">ref-CAMERA.html</xsl:when>
    <xsl:when test="$gi='caption'">ref-CAPTION.html</xsl:when>
    <xsl:when test="$gi='case'">ref-CASE.html</xsl:when>
    <xsl:when test="$gi='castGroup'">ref-CASTGRP.html</xsl:when>
    <xsl:when test="$gi='castItem'">ref-CASTITEM.html</xsl:when>
    <xsl:when test="$gi='castList'">ref-CASTLIST.html</xsl:when>
    <xsl:when test="$gi='catDesc'">ref-CATDESC.html</xsl:when>
    <xsl:when test="$gi='category'">ref-CATEGORY.html</xsl:when>
    <xsl:when test="$gi='catRef'">ref-CATREF.html</xsl:when>
    <xsl:when test="$gi='cell'">ref-CELL.html</xsl:when>
    <xsl:when test="$gi='certainty'">ref-CERTAIN.html</xsl:when>
    <xsl:when test="$gi='change'">ref-CHANGE.html</xsl:when>
    <xsl:when test="$gi='channel'">ref-CHANNEL.html</xsl:when>
    <xsl:when test="$gi='children'">ref-CHILDREN.html</xsl:when>
    <xsl:when test="$gi='cit'">ref-CIT.html</xsl:when>
    <xsl:when test="$gi='cl'">ref-CL.html</xsl:when>
    <xsl:when test="$gi='classDecl'">ref-CLASDECL.html</xsl:when>
    <xsl:when test="$gi='class'">ref-CLASS.html</xsl:when>
    <xsl:when test="$gi='classCode'">ref-CLASSCOD.html</xsl:when>
    <xsl:when test="$gi='classDoc'">ref-CLASSDOC.html</xsl:when>
    <xsl:when test="$gi='classes'">ref-CLASSES.html</xsl:when>
    <xsl:when test="$gi='closer'">ref-CLOSER.html</xsl:when>
    <xsl:when test="$gi='cb'">ref-COLBR.html</xsl:when>
    <xsl:when test="$gi='colloc'">ref-COLLOC.html</xsl:when>
    <xsl:when test="$gi='cond'">ref-COND.html</xsl:when>
    <xsl:when test="$gi='constitution'">ref-CONSTITN.html</xsl:when>
    <xsl:when test="$gi='corr'">ref-CORR.html</xsl:when>
    <xsl:when test="$gi='correction'">ref-CORRECTN.html</xsl:when>
    <xsl:when test="$gi='country'">ref-COUNTRY.html</xsl:when>
    <xsl:when test="$gi='creation'">ref-CREATN.html</xsl:when>
    <xsl:when test="$gi='damage'">ref-DAMAGE.html</xsl:when>
    <xsl:when test="$gi='dataDesc'">ref-DATADESC.html</xsl:when>
    <xsl:when test="$gi='datatype'">ref-DATATYPE.html</xsl:when>
    <xsl:when test="$gi='date'">ref-DATE.html</xsl:when>
    <xsl:when test="$gi='dateline'">ref-DATELINE.html</xsl:when>
    <xsl:when test="$gi='dateRange'">ref-DATERANG.html</xsl:when>
    <xsl:when test="$gi='dateStruct'">ref-DATESTRU.html</xsl:when>
    <xsl:when test="$gi='day'">ref-DAY.html</xsl:when>
    <xsl:when test="$gi='def'">ref-DEF.html</xsl:when>
    <xsl:when test="$gi='default'">ref-DEFAULT.html</xsl:when>
    <xsl:when test="$gi='del'">ref-DEL.html</xsl:when>
    <xsl:when test="$gi='delSpan'">ref-DELSPAN.html</xsl:when>
    <xsl:when test="$gi='derivation'">ref-DERIVATN.html</xsl:when>
    <xsl:when test="$gi='desc'">ref-DESC.html</xsl:when>
    <xsl:when test="$gi='descrip'">ref-DESCRIP.html</xsl:when>
    <xsl:when test="$gi='dft'">ref-DFT.html</xsl:when>
    <xsl:when test="$gi='dictScrap'">ref-DICSCRAP.html</xsl:when>
    <xsl:when test="$gi='egDI'">ref-DIEG.html</xsl:when>
    <xsl:when test="$gi='direction'">ref-DIRECTN.html</xsl:when>
    <xsl:when test="$gi='distance'">ref-DISTANCE.html</xsl:when>
    <xsl:when test="$gi='distinct'">ref-DISTINCT.html</xsl:when>
    <xsl:when test="$gi='distributor'">ref-DISTRIB.html</xsl:when>
    <xsl:when test="$gi='div'">ref-DIV.html</xsl:when>
    <xsl:when test="$gi='div0'">ref-DIV0.html</xsl:when>
    <xsl:when test="$gi='div1'">ref-DIV1.html</xsl:when>
    <xsl:when test="$gi='div2'">ref-DIV2.html</xsl:when>
    <xsl:when test="$gi='div3'">ref-DIV3.html</xsl:when>
    <xsl:when test="$gi='div4'">ref-DIV4.html</xsl:when>
    <xsl:when test="$gi='div5'">ref-DIV5.html</xsl:when>
    <xsl:when test="$gi='div6'">ref-DIV6.html</xsl:when>
    <xsl:when test="$gi='div7'">ref-DIV7.html</xsl:when>
    <xsl:when test="$gi='divGen'">ref-DIVGEN.html</xsl:when>
    <xsl:when test="$gi='docAuthor'">ref-DOCAUTH.html</xsl:when>
    <xsl:when test="$gi='docDate'">ref-DOCDATE.html</xsl:when>
    <xsl:when test="$gi='docEdition'">ref-DOCEDITN.html</xsl:when>
    <xsl:when test="$gi='docImprint'">ref-DOCIMPRT.html</xsl:when>
    <xsl:when test="$gi='docTitle'">ref-DOCTITLE.html</xsl:when>
    <xsl:when test="$gi='domain'">ref-DOMAIN.html</xsl:when>
    <xsl:when test="$gi='role'">ref-DRROLE.html</xsl:when>
    <xsl:when test="$gi='editorialDecl'">ref-EDDECL.html</xsl:when>
    <xsl:when test="$gi='edition'">ref-EDITION.html</xsl:when>
    <xsl:when test="$gi='editor'">ref-EDITOR.html</xsl:when>
    <xsl:when test="$gi='editionStmt'">ref-EDSTMT.html</xsl:when>
    <xsl:when test="$gi='education'">ref-EDUCN.html</xsl:when>
    <xsl:when test="$gi='eLeaf'">ref-ELEAF.html</xsl:when>
    <xsl:when test="$gi='elemDecl'">ref-ELEMDECL.html</xsl:when>
    <xsl:when test="$gi='emph'">ref-EMPH.html</xsl:when>
    <xsl:when test="$gi='encodingDesc'">ref-ENCDESC.html</xsl:when>
    <xsl:when test="$gi='entDoc'">ref-ENTDOC.html</xsl:when>
    <xsl:when test="$gi='entName'">ref-ENTNAME.html</xsl:when>
    <xsl:when test="$gi='entry'">ref-ENTRY.html</xsl:when>
    <xsl:when test="$gi='entryFree'">ref-ENTRYFR.html</xsl:when>
    <xsl:when test="$gi='epigraph'">ref-EPIGRAPH.html</xsl:when>
    <xsl:when test="$gi='epilogue'">ref-EPILOGUE.html</xsl:when>
    <xsl:when test="$gi='equipment'">ref-EQUIPMEN.html</xsl:when>
    <xsl:when test="$gi='equiv'">ref-EQUIV.html</xsl:when>
    <xsl:when test="$gi='eTree'">ref-ETREE.html</xsl:when>
    <xsl:when test="$gi='etym'">ref-ETYM.html</xsl:when>
    <xsl:when test="$gi='event'">ref-EVENT.html</xsl:when>
    <xsl:when test="$gi='exceptions'">ref-EXCEPTNS.html</xsl:when>
    <xsl:when test="$gi='exemplum'">ref-EXEMPLUM.html</xsl:when>
    <xsl:when test="$gi='expan'">ref-EXPAN.html</xsl:when>
    <xsl:when test="$gi='extent'">ref-EXTENT.html</xsl:when>
    <xsl:when test="$gi='f'">ref-F.html</xsl:when>
    <xsl:when test="$gi='factuality'">ref-FACTUAL.html</xsl:when>
    <xsl:when test="$gi='fAlt'">ref-FALT.html</xsl:when>
    <xsl:when test="$gi='fDecl'">ref-FDECL.html</xsl:when>
    <xsl:when test="$gi='fDescr'">ref-FDESCR.html</xsl:when>
    <xsl:when test="$gi='figDesc'">ref-FIGDESC.html</xsl:when>
    <xsl:when test="$gi='figure'">ref-FIGURE.html</xsl:when>
    <xsl:when test="$gi='fileDesc'">ref-FILDESC.html</xsl:when>
    <xsl:when test="$gi='files'">ref-FILES.html</xsl:when>
    <xsl:when test="$gi='fLib'">ref-FLIB.html</xsl:when>
    <xsl:when test="$gi='foreign'">ref-FOREIGN.html</xsl:when>
    <xsl:when test="$gi='foreName'">ref-FORENAME.html</xsl:when>
    <xsl:when test="$gi='forest'">ref-FOREST.html</xsl:when>
    <xsl:when test="$gi='forestGrp'">ref-FORESTGP.html</xsl:when>
    <xsl:when test="$gi='form'">ref-FORM.html</xsl:when>
    <xsl:when test="$gi='formula'">ref-FORMULA.html</xsl:when>
    <xsl:when test="$gi='front'">ref-FRONT.html</xsl:when>
    <xsl:when test="$gi='firstLang'">ref-FRSTLANG.html</xsl:when>
    <xsl:when test="$gi='fsConstraints'">ref-FSCONSTR.html</xsl:when>
    <xsl:when test="$gi='fsdDecl'">ref-FSDDECL.html</xsl:when>
    <xsl:when test="$gi='fsDecl'">ref-FSDECL.html</xsl:when>
    <xsl:when test="$gi='fsDescr'">ref-FSDESCR.html</xsl:when>
    <xsl:when test="$gi='fsLib'">ref-FSLIB.html</xsl:when>
    <xsl:when test="$gi='fs'">ref-FSTAG.html</xsl:when>
    <xsl:when test="$gi='funder'">ref-FUNDER.html</xsl:when>
    <xsl:when test="$gi='fvLib'">ref-FVLIB.html</xsl:when>
    <xsl:when test="$gi='fw'">ref-FW.html</xsl:when>
    <xsl:when test="$gi='gap'">ref-GAP.html</xsl:when>
    <xsl:when test="$gi='gen'">ref-GEN.html</xsl:when>
    <xsl:when test="$gi='genName'">ref-GENNAME.html</xsl:when>
    <xsl:when test="$gi='geog'">ref-GEOG.html</xsl:when>
    <xsl:when test="$gi='geogName'">ref-GEOGNAME.html</xsl:when>
    <xsl:when test="$gi='gi'">ref-GI.html</xsl:when>
    <xsl:when test="$gi='gloss'">ref-GLOSS.html</xsl:when>
    <xsl:when test="$gi='gram'">ref-GRAM.html</xsl:when>
    <xsl:when test="$gi='gramGrp'">ref-GRAMGRP.html</xsl:when>
    <xsl:when test="$gi='graph'">ref-GRAPH.html</xsl:when>
    <xsl:when test="$gi='group'">ref-GROUP.html</xsl:when>
    <xsl:when test="$gi='hand'">ref-HAND.html</xsl:when>
    <xsl:when test="$gi='handList'">ref-HANDLIST.html</xsl:when>
    <xsl:when test="$gi='handShift'">ref-HANDSHFT.html</xsl:when>
    <xsl:when test="$gi='head'">ref-HEAD.html</xsl:when>
    <xsl:when test="$gi='headItem'">ref-HEADIT.html</xsl:when>
    <xsl:when test="$gi='headLabel'">ref-HEADLAB.html</xsl:when>
    <xsl:when test="$gi='hi'">ref-HI.html</xsl:when>
    <xsl:when test="$gi='hom'">ref-HOM.html</xsl:when>
    <xsl:when test="$gi='hour'">ref-HOUR.html</xsl:when>
    <xsl:when test="$gi='hyph'">ref-HYPH.html</xsl:when>
    <xsl:when test="$gi='hyphenation'">ref-HYPHEN.html</xsl:when>
    <xsl:when test="$gi='idno'">ref-IDNO.html</xsl:when>
    <xsl:when test="$gi='if'">ref-IF.html</xsl:when>
    <xsl:when test="$gi='iff'">ref-IFF.html</xsl:when>
    <xsl:when test="$gi='ihs'">ref-IHS.html</xsl:when>
    <xsl:when test="$gi='imprimatur'">ref-IMPRIMAT.html</xsl:when>
    <xsl:when test="$gi='imprint'">ref-IMPRINT.html</xsl:when>
    <xsl:when test="$gi='index'">ref-INDEX.html</xsl:when>
    <xsl:when test="$gi='iNode'">ref-INODE.html</xsl:when>
    <xsl:when test="$gi='interaction'">ref-INTERACT.html</xsl:when>
    <xsl:when test="$gi='interp'">ref-INTERP.html</xsl:when>
    <xsl:when test="$gi='interpGrp'">ref-INTERPGP.html</xsl:when>
    <xsl:when test="$gi='interpretation'">ref-INTERPTN.html</xsl:when>
    <xsl:when test="$gi='item'">ref-ITEM.html</xsl:when>
    <xsl:when test="$gi='itype'">ref-ITYPE.html</xsl:when>
    <xsl:when test="$gi='join'">ref-JOIN.html</xsl:when>
    <xsl:when test="$gi='joinGrp'">ref-JOINGRP.html</xsl:when>
    <xsl:when test="$gi='keywords'">ref-KEYWORDS.html</xsl:when>
    <xsl:when test="$gi='kinesic'">ref-KINESIC.html</xsl:when>
    <xsl:when test="$gi='l'">ref-L.html</xsl:when>
    <xsl:when test="$gi='label'">ref-LABEL.html</xsl:when>
    <xsl:when test="$gi='lacunaEnd'">ref-LACEND.html</xsl:when>
    <xsl:when test="$gi='lacunaStart'">ref-LACSTART.html</xsl:when>
    <xsl:when test="$gi='lang'">ref-LANG.html</xsl:when>
    <xsl:when test="$gi='langKnown'">ref-LANGKNOW.html</xsl:when>
    <xsl:when test="$gi='language'">ref-LANGUAGE.html</xsl:when>
    <xsl:when test="$gi='langUsage'">ref-LANGUSG.html</xsl:when>
    <xsl:when test="$gi='lbl'">ref-LBL.html</xsl:when>
    <xsl:when test="$gi='leaf'">ref-LEAF.html</xsl:when>
    <xsl:when test="$gi='lem'">ref-LEM.html</xsl:when>
    <xsl:when test="$gi='lg'">ref-LG.html</xsl:when>
    <xsl:when test="$gi='lg1'">ref-LG1.html</xsl:when>
    <xsl:when test="$gi='lg2'">ref-LG2.html</xsl:when>
    <xsl:when test="$gi='lg3'">ref-LG3.html</xsl:when>
    <xsl:when test="$gi='lg4'">ref-LG4.html</xsl:when>
    <xsl:when test="$gi='lg5'">ref-LG5.html</xsl:when>
    <xsl:when test="$gi='lb'">ref-LINEBR.html</xsl:when>
    <xsl:when test="$gi='link'">ref-LINK.html</xsl:when>
    <xsl:when test="$gi='linkGrp'">ref-LINKGRP.html</xsl:when>
    <xsl:when test="$gi='list'">ref-LIST.html</xsl:when>
    <xsl:when test="$gi='listBibl'">ref-LISTBIBL.html</xsl:when>
    <xsl:when test="$gi='locale'">ref-LOCALE.html</xsl:when>
    <xsl:when test="$gi='m'">ref-M.html</xsl:when>
    <xsl:when test="$gi='measure'">ref-MEASURE.html</xsl:when>
    <xsl:when test="$gi='meeting'">ref-MEETING.html</xsl:when>
    <xsl:when test="$gi='mentioned'">ref-MENTIOND.html</xsl:when>
    <xsl:when test="$gi='metDecl'">ref-METDECL.html</xsl:when>
    <xsl:when test="$gi='milestone'">ref-MILEST.html</xsl:when>
    <xsl:when test="$gi='minus'">ref-MINUS.html</xsl:when>
    <xsl:when test="$gi='minute'">ref-MINUTE.html</xsl:when>
    <xsl:when test="$gi='monogr'">ref-MONOGR.html</xsl:when>
    <xsl:when test="$gi='month'">ref-MONTH.html</xsl:when>
    <xsl:when test="$gi='mood'">ref-MOOD.html</xsl:when>
    <xsl:when test="$gi='move'">ref-MOVE.html</xsl:when>
    <xsl:when test="$gi='msr'">ref-MSR.html</xsl:when>
    <xsl:when test="$gi='name'">ref-NAME.html</xsl:when>
    <xsl:when test="$gi='nameLink'">ref-NAMELINK.html</xsl:when>
    <xsl:when test="$gi='nbr'">ref-NBR.html</xsl:when>
    <xsl:when test="$gi='node'">ref-NODE.html</xsl:when>
    <xsl:when test="$gi='none'">ref-NONE.html</xsl:when>
    <xsl:when test="$gi='normalization'">ref-NORMALZN.html</xsl:when>
    <xsl:when test="$gi='note'">ref-NOTE.html</xsl:when>
    <xsl:when test="$gi='notesStmt'">ref-NOTSTMT.html</xsl:when>
    <xsl:when test="$gi='null'">ref-NULL.html</xsl:when>
    <xsl:when test="$gi='num'">ref-NUM.html</xsl:when>
    <xsl:when test="$gi='number'">ref-NUMBER.html</xsl:when>
    <xsl:when test="$gi='occasion'">ref-OCCASION.html</xsl:when>
    <xsl:when test="$gi='occupation'">ref-OCCUPAT.html</xsl:when>
    <xsl:when test="$gi='offset'">ref-OFFSET.html</xsl:when>
    <xsl:when test="$gi='ofig'">ref-OFIG.html</xsl:when>
    <xsl:when test="$gi='opener'">ref-OPENER.html</xsl:when>
    <xsl:when test="$gi='oRef'">ref-OREF.html</xsl:when>
    <xsl:when test="$gi='orgDivn'">ref-ORGDIVN.html</xsl:when>
    <xsl:when test="$gi='orgName'">ref-ORGNAME.html</xsl:when>
    <xsl:when test="$gi='orgTitle'">ref-ORGTITLE.html</xsl:when>
    <xsl:when test="$gi='orgType'">ref-ORGTYPE.html</xsl:when>
    <xsl:when test="$gi='orig'">ref-ORIG.html</xsl:when>
    <xsl:when test="$gi='orth'">ref-ORTH.html</xsl:when>
    <xsl:when test="$gi='otherForm'">ref-OTHFORM.html</xsl:when>
    <xsl:when test="$gi='oVar'">ref-OVAR.html</xsl:when>
    <xsl:when test="$gi='p'">ref-P.html</xsl:when>
    <xsl:when test="$gi='pb'">ref-PAGEBR.html</xsl:when>
    <xsl:when test="$gi='parents'">ref-PARENTS.html</xsl:when>
    <xsl:when test="$gi='part'">ref-PART.html</xsl:when>
    <xsl:when test="$gi='particDesc'">ref-PARTDESC.html</xsl:when>
    <xsl:when test="$gi='particLinks'">ref-PARTIREL.html</xsl:when>
    <xsl:when test="$gi='pause'">ref-PAUSE.html</xsl:when>
    <xsl:when test="$gi='per'">ref-PER.html</xsl:when>
    <xsl:when test="$gi='performance'">ref-PERFORM.html</xsl:when>
    <xsl:when test="$gi='personGrp'">ref-PERSGRP.html</xsl:when>
    <xsl:when test="$gi='persName'">ref-PERSNAME.html</xsl:when>
    <xsl:when test="$gi='person'">ref-PERSON.html</xsl:when>
    <xsl:when test="$gi='phr'">ref-PHR.html</xsl:when>
    <xsl:when test="$gi='placeName'">ref-PLACNAME.html</xsl:when>
    <xsl:when test="$gi='col'">ref-PLCOL.html</xsl:when>
    <xsl:when test="$gi='line'">ref-PLLINE.html</xsl:when>
    <xsl:when test="$gi='page'">ref-PLPAGE.html</xsl:when>
    <xsl:when test="$gi='plus'">ref-PLUS.html</xsl:when>
    <xsl:when test="$gi='vol'">ref-PLVOL.html</xsl:when>
    <xsl:when test="$gi='pos'">ref-POS.html</xsl:when>
    <xsl:when test="$gi='postBox'">ref-POSTBOX.html</xsl:when>
    <xsl:when test="$gi='postCode'">ref-POSTCODE.html</xsl:when>
    <xsl:when test="$gi='pRef'">ref-PREF.html</xsl:when>
    <xsl:when test="$gi='preparedness'">ref-PREPNESS.html</xsl:when>
    <xsl:when test="$gi='principal'">ref-PRINCIPL.html</xsl:when>
    <xsl:when test="$gi='profileDesc'">ref-PROFDESC.html</xsl:when>
    <xsl:when test="$gi='projectDesc'">ref-PROJDESC.html</xsl:when>
    <xsl:when test="$gi='prologue'">ref-PROLOGUE.html</xsl:when>
    <xsl:when test="$gi='pron'">ref-PRON.html</xsl:when>
    <xsl:when test="$gi='ptr'">ref-PTR.html</xsl:when>
    <xsl:when test="$gi='publisher'">ref-PUBLISHR.html</xsl:when>
    <xsl:when test="$gi='pubPlace'">ref-PUBPLACE.html</xsl:when>
    <xsl:when test="$gi='publicationStmt'">ref-PUBSTMT.html</xsl:when>
    <xsl:when test="$gi='purpose'">ref-PURPOSE.html</xsl:when>
    <xsl:when test="$gi='pVar'">ref-PVAR.html</xsl:when>
    <xsl:when test="$gi='q'">ref-Q.html</xsl:when>
    <xsl:when test="$gi='quote'">ref-QUOTE.html</xsl:when>
    <xsl:when test="$gi='quotation'">ref-QUOTN.html</xsl:when>
    <xsl:when test="$gi='rate'">ref-RATE.html</xsl:when>
    <xsl:when test="$gi='rdg'">ref-RDG.html</xsl:when>
    <xsl:when test="$gi='rdgGrp'">ref-RDGGRP.html</xsl:when>
    <xsl:when test="$gi='re'">ref-RE.html</xsl:when>
    <xsl:when test="$gi='recording'">ref-RECORDIN.html</xsl:when>
    <xsl:when test="$gi='recordingStmt'">ref-RECSTMT.html</xsl:when>
    <xsl:when test="$gi='ref'">ref-REF.html</xsl:when>
    <xsl:when test="$gi='refsDecl'">ref-REFSDECL.html</xsl:when>
    <xsl:when test="$gi='reg'">ref-REG.html</xsl:when>
    <xsl:when test="$gi='region'">ref-REGION.html</xsl:when>
    <xsl:when test="$gi='relation'">ref-RELATION.html</xsl:when>
    <xsl:when test="$gi='remarks'">ref-REMARKS.html</xsl:when>
    <xsl:when test="$gi='rendition'">ref-RENDITN.html</xsl:when>
    <xsl:when test="$gi='residence'">ref-RESIDENC.html</xsl:when>
    <xsl:when test="$gi='respStmt'">ref-RESP.html</xsl:when>
    <xsl:when test="$gi='respons'">ref-RESPONS.html</xsl:when>
    <xsl:when test="$gi='restore'">ref-RESTORE.html</xsl:when>
    <xsl:when test="$gi='revisionDesc'">ref-REVDESC.html</xsl:when>
    <xsl:when test="$gi='resp'">ref-ROLE.html</xsl:when>
    <xsl:when test="$gi='roleDesc'">ref-ROLEDESC.html</xsl:when>
    <xsl:when test="$gi='roleName'">ref-ROLENAME.html</xsl:when>
    <xsl:when test="$gi='root'">ref-ROOT.html</xsl:when>
    <xsl:when test="$gi='row'">ref-ROW.html</xsl:when>
    <xsl:when test="$gi='rs'">ref-RS.html</xsl:when>
    <xsl:when test="$gi='s'">ref-S.html</xsl:when>
    <xsl:when test="$gi='salute'">ref-SALUTE.html</xsl:when>
    <xsl:when test="$gi='samplingDecl'">ref-SAMPDECL.html</xsl:when>
    <xsl:when test="$gi='script'">ref-SCRIPT.html</xsl:when>
    <xsl:when test="$gi='scriptStmt'">ref-SCRSTMT.html</xsl:when>
    <xsl:when test="$gi='second'">ref-SECOND.html</xsl:when>
    <xsl:when test="$gi='seg'">ref-SEG.html</xsl:when>
    <xsl:when test="$gi='segmentation'">ref-SEGMENTN.html</xsl:when>
    <xsl:when test="$gi='sense'">ref-SENSE.html</xsl:when>
    <xsl:when test="$gi='series'">ref-SERIES.html</xsl:when>
    <xsl:when test="$gi='seriesStmt'">ref-SERSTMT.html</xsl:when>
    <xsl:when test="$gi='set'">ref-SET.html</xsl:when>
    <xsl:when test="$gi='settingDesc'">ref-SETTDESC.html</xsl:when>
    <xsl:when test="$gi='setting'">ref-SETTING.html</xsl:when>
    <xsl:when test="$gi='settlement'">ref-SETTLE.html</xsl:when>
    <xsl:when test="$gi='shift'">ref-SHIFT.html</xsl:when>
    <xsl:when test="$gi='sic'">ref-SIC.html</xsl:when>
    <xsl:when test="$gi='signed'">ref-SIGNED.html</xsl:when>
    <xsl:when test="$gi='soCalled'">ref-SOCALLED.html</xsl:when>
    <xsl:when test="$gi='socecStatus'">ref-SOCECSTA.html</xsl:when>
    <xsl:when test="$gi='sound'">ref-SOUND.html</xsl:when>
    <xsl:when test="$gi='sourceDesc'">ref-SOUSTMT.html</xsl:when>
    <xsl:when test="$gi='sp'">ref-SP.html</xsl:when>
    <xsl:when test="$gi='space'">ref-SPACE.html</xsl:when>
    <xsl:when test="$gi='span'">ref-SPAN.html</xsl:when>
    <xsl:when test="$gi='spanGrp'">ref-SPANGRP.html</xsl:when>
    <xsl:when test="$gi='speaker'">ref-SPEAKER.html</xsl:when>
    <xsl:when test="$gi='sponsor'">ref-SPONSOR.html</xsl:when>
    <xsl:when test="$gi='stage'">ref-STAGE.html</xsl:when>
    <xsl:when test="$gi='state'">ref-STATE.html</xsl:when>
    <xsl:when test="$gi='stdVals'">ref-STDVALS.html</xsl:when>
    <xsl:when test="$gi='step'">ref-STEP.html</xsl:when>
    <xsl:when test="$gi='str'">ref-STR.html</xsl:when>
    <xsl:when test="$gi='street'">ref-STREET.html</xsl:when>
    <xsl:when test="$gi='stress'">ref-STRESS.html</xsl:when>
    <xsl:when test="$gi='string'">ref-STRING.html</xsl:when>
    <xsl:when test="$gi='subc'">ref-SUBC.html</xsl:when>
    <xsl:when test="$gi='superEntry'">ref-SUPENTRY.html</xsl:when>
    <xsl:when test="$gi='supplied'">ref-SUPPLIED.html</xsl:when>
    <xsl:when test="$gi='surname'">ref-SURNAME.html</xsl:when>
    <xsl:when test="$gi='syll'">ref-SYLL.html</xsl:when>
    <xsl:when test="$gi='sym'">ref-SYM.html</xsl:when>
    <xsl:when test="$gi='symbol'">ref-SYMBOL.html</xsl:when>
    <xsl:when test="$gi='table'">ref-TABLE.html</xsl:when>
    <xsl:when test="$gi='tag'">ref-TAG.html</xsl:when>
    <xsl:when test="$gi='tagDoc'">ref-TAGDOC.html</xsl:when>
    <xsl:when test="$gi='tagsDecl'">ref-TAGSDECL.html</xsl:when>
    <xsl:when test="$gi='tagUsage'">ref-TAGUSAGE.html</xsl:when>
    <xsl:when test="$gi='taxonomy'">ref-TAXONOMY.html</xsl:when>
    <xsl:when test="$gi='egTD'">ref-TDEG.html</xsl:when>
    <xsl:when test="$gi='tech'">ref-TECH.html</xsl:when>
    <xsl:when test="$gi='TEI.2'">ref-TEI2.html</xsl:when>
    <xsl:when test="$gi='teiCorpus.2'">ref-TEICORP2.html</xsl:when>
    <xsl:when test="$gi='teiFsd2'">ref-TEIFSD2.html</xsl:when>
    <xsl:when test="$gi='teiHeader'">ref-TEIHEAD.html</xsl:when>
    <xsl:when test="$gi='writingSystemDeclaration'">ref-TEIWSD.html</xsl:when>
    <xsl:when test="$gi='term'">ref-TERM.html</xsl:when>
    <xsl:when test="$gi='termEntryF'">ref-TERMENTF.html</xsl:when>
    <xsl:when test="$gi='termEntryN'">ref-TERMENTN.html</xsl:when>
    <xsl:when test="$gi='text'">ref-TEXT.html</xsl:when>
    <xsl:when test="$gi='textClass'">ref-TEXTCLAS.html</xsl:when>
    <xsl:when test="$gi='textDesc'">ref-TEXTDESC.html</xsl:when>
    <xsl:when test="$gi='then'">ref-THEN.html</xsl:when>
    <xsl:when test="$gi='tig'">ref-TIG.html</xsl:when>
    <xsl:when test="$gi='time'">ref-TIME.html</xsl:when>
    <xsl:when test="$gi='timeline'">ref-TIMELINE.html</xsl:when>
    <xsl:when test="$gi='timeRange'">ref-TIMERANG.html</xsl:when>
    <xsl:when test="$gi='timeStruct'">ref-TIMESTRU.html</xsl:when>
    <xsl:when test="$gi='title'">ref-TITLE.html</xsl:when>
    <xsl:when test="$gi='titlePage'">ref-TITLEPA.html</xsl:when>
    <xsl:when test="$gi='titlePart'">ref-TITLEPT.html</xsl:when>
    <xsl:when test="$gi='titleStmt'">ref-TITSTMT.html</xsl:when>
    <xsl:when test="$gi='tns'">ref-TNS.html</xsl:when>
    <xsl:when test="$gi='tr'">ref-TR.html</xsl:when>
    <xsl:when test="$gi='trailer'">ref-TRAILER.html</xsl:when>
    <xsl:when test="$gi='trans'">ref-TRANS.html</xsl:when>
    <xsl:when test="$gi='tree'">ref-TREE.html</xsl:when>
    <xsl:when test="$gi='triangle'">ref-TRIANGLE.html</xsl:when>
    <xsl:when test="$gi='tsd'">ref-TSD.html</xsl:when>
    <xsl:when test="$gi='u'">ref-U.html</xsl:when>
    <xsl:when test="$gi='uncertain'">ref-UNCERT.html</xsl:when>
    <xsl:when test="$gi='unclear'">ref-UNCLEAR.html</xsl:when>
    <xsl:when test="$gi='usg'">ref-USG.html</xsl:when>
    <xsl:when test="$gi='val'">ref-VAL.html</xsl:when>
    <xsl:when test="$gi='valDesc'">ref-VALDESC.html</xsl:when>
    <xsl:when test="$gi='valList'">ref-VALLIST.html</xsl:when>
    <xsl:when test="$gi='vAlt'">ref-VALT.html</xsl:when>
    <xsl:when test="$gi='variantEncoding'">ref-VARENCOD.html</xsl:when>
    <xsl:when test="$gi='vDefault'">ref-VDFT.html</xsl:when>
    <xsl:when test="$gi='version'">ref-VERNAME.html</xsl:when>
    <xsl:when test="$gi='view'">ref-VIEW.html</xsl:when>
    <xsl:when test="$gi='vocal'">ref-VOCAL.html</xsl:when>
    <xsl:when test="$gi='vRange'">ref-VRANGE.html</xsl:when>
    <xsl:when test="$gi='w'">ref-W.html</xsl:when>
    <xsl:when test="$gi='week'">ref-WEEK.html</xsl:when>
    <xsl:when test="$gi='when'">ref-WHEN.html</xsl:when>
    <xsl:when test="$gi='wit'">ref-WIT.html</xsl:when>
    <xsl:when test="$gi='witDetail'">ref-WITDTL.html</xsl:when>
    <xsl:when test="$gi='witEnd'">ref-WITEND.html</xsl:when>
    <xsl:when test="$gi='witList'">ref-WITLIST.html</xsl:when>
    <xsl:when test="$gi='witness'">ref-WITNESS.html</xsl:when>
    <xsl:when test="$gi='witStart'">ref-WITSTART.html</xsl:when>
    <xsl:when test="$gi='writing'">ref-WRITING.html</xsl:when>
    <xsl:when test="$gi='codedCharSet'">ref-WSDCCS.html</xsl:when>
    <xsl:when test="$gi='character'">ref-WSDCHAR.html</xsl:when>
    <xsl:when test="$gi='characters'">ref-WSDCHARS.html</xsl:when>
    <xsl:when test="$gi='desc'">ref-WSDDESC.html</xsl:when>
    <xsl:when test="$gi='entitySet'">ref-WSDENTS.html</xsl:when>
    <xsl:when test="$gi='figure'">ref-WSDFIG.html</xsl:when>
    <xsl:when test="$gi='form'">ref-WSDFORM.html</xsl:when>
    <xsl:when test="$gi='languageWSD'">ref-WSDLANG.html</xsl:when>
    <xsl:when test="$gi='noteWSD'">ref-WSDNOTE.html</xsl:when>
    <xsl:when test="$gi='extFigure'">ref-WSDXFIG.html</xsl:when>
    <xsl:when test="$gi='xptr'">ref-XPTR.html</xsl:when>
    <xsl:when test="$gi='xr'">ref-XR.html</xsl:when>
    <xsl:when test="$gi='xref'">ref-XREF.html</xsl:when>
    <xsl:when test="$gi='year'">ref-YEAR.html</xsl:when>
  </xsl:choose>
</xsl:template>

<!-- I18N -->
<xsl:param name="LABELATT-type">
  <xsl:choose>
    <xsl:when test="$lang = 'en'">type</xsl:when>
    <xsl:when test="$lang = 'sl'">tip</xsl:when>
  </xsl:choose>
</xsl:param>
<xsl:param name="LABELATT-lang">
  <xsl:choose>
    <xsl:when test="$lang = 'en'">language</xsl:when>
    <xsl:when test="$lang = 'sl'">jezik</xsl:when>
  </xsl:choose>
</xsl:param>
<xsl:param name="LABELATT-creator">
  <xsl:choose>
    <xsl:when test="$lang = 'en'">created</xsl:when>
    <xsl:when test="$lang = 'sl'">zapisal</xsl:when>
  </xsl:choose>
</xsl:param>
<xsl:param name="LABELATT-date">
  <xsl:choose>
    <xsl:when test="$lang = 'en'">date</xsl:when>
    <xsl:when test="$lang = 'sl'">datum</xsl:when>
  </xsl:choose>
</xsl:param>
<xsl:param name="LABELATT-date.created">
  <xsl:choose>
    <xsl:when test="$lang = 'en'">created</xsl:when>
    <xsl:when test="$lang = 'sl'">napisano</xsl:when>
  </xsl:choose>
</xsl:param>
<xsl:param name="LABELATT-date.updated">
  <xsl:choose>
    <xsl:when test="$lang = 'en'">updated</xsl:when>
    <xsl:when test="$lang = 'sl'">popravljeno</xsl:when>
  </xsl:choose>
</xsl:param>


<xsl:param name="LABEL-teiHeader">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">teiHeader</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">TEI Header</xsl:when>
      <xsl:when test="$lang = 'sl'">Kolofon TEI</xsl:when>
    </xsl:choose>
  </A>
</xsl:param>
<xsl:param name="LABEL-fileDesc">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">fileDesc</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">File Description</xsl:when>
      <xsl:when test="$lang = 'sl'">Opis datoteke</xsl:when>
    </xsl:choose>
  </A>
</xsl:param>
<xsl:param name="LABEL-sourceDesc">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">sourceDesc</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">Source Description</xsl:when>
      <xsl:when test="$lang = 'sl'">Opis vira</xsl:when>
    </xsl:choose>
  </A>
</xsl:param>
<xsl:param name="LABEL-encodingDesc">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">encodingDesc</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">Encoding Description</xsl:when>
      <xsl:when test="$lang = 'sl'">Opis zapisa</xsl:when>
    </xsl:choose>
  </A>
</xsl:param>
<xsl:param name="LABEL-projectDesc">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">projectDesc</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">Project description</xsl:when>
      <xsl:when test="$lang = 'sl'">Opis projekta</xsl:when>
    </xsl:choose>
  </A>
</xsl:param>
<xsl:param name="LABEL-profileDesc">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">profileDesc</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">Profile Description</xsl:when>
      <xsl:when test="$lang = 'sl'">Opis karakteristik</xsl:when>
    </xsl:choose>
  </A>
</xsl:param>
<xsl:param name="LABEL-revisionDesc">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">revisionDesc</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">Revision Description</xsl:when>
      <xsl:when test="$lang = 'sl'">Opis sprememb</xsl:when>
    </xsl:choose>
  </A>
</xsl:param>
<xsl:param name="LABEL-titleStmt">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">titleStmt</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">Title Statement</xsl:when>
      <xsl:when test="$lang = 'sl'">Naslovna izjava</xsl:when>
    </xsl:choose>
  </A>
</xsl:param>
<xsl:param name="LABEL-publicationStmt">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">publicationStmt</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">Publication Statement</xsl:when>
      <xsl:when test="$lang = 'sl'">Izjava o objavi</xsl:when>
    </xsl:choose>
  </A>
</xsl:param>
<xsl:param name="LABEL-notesStmt">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">notesStmt</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">Notes Statement</xsl:when>
      <xsl:when test="$lang = 'sl'">Dodatne opombe</xsl:when>
    </xsl:choose>
  </A>
</xsl:param>
<xsl:param name="LABEL-respStmt">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">respStmt</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">Responsibility Statement</xsl:when>
      <xsl:when test="$lang = 'sl'">Izjava o odgovornosti</xsl:when>
    </xsl:choose>
  </A>
</xsl:param>
<xsl:param name="LABEL-editionStmt">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">editionStmt</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">Edition Statement</xsl:when>
      <xsl:when test="$lang = 'sl'">Izjava o ediciji</xsl:when>
    </xsl:choose>
  </A>
</xsl:param>
<xsl:param name="LABEL-editorialDecl">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">editorialDecl</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">Editorial declaration</xsl:when>
      <xsl:when test="$lang = 'sl'">Uredni&#353;ka deklaracija</xsl:when>
    </xsl:choose>
  </A>
</xsl:param>
<!-- USER EXTENSION a la P5 -->
<xsl:param name="LABEL-charDesc">
  <A href="http://www.tei-c.org/P5/Guidelines/ref-charDesc.html">
    <xsl:choose>
      <xsl:when test="$lang = 'en'">Character description</xsl:when>
      <xsl:when test="$lang = 'sl'">Opis znakov</xsl:when>
    </xsl:choose>
  </A>
</xsl:param>
<xsl:param name="LABEL-tagsDecl">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">tagsDecl</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">Tags declaration</xsl:when>
      <xsl:when test="$lang = 'sl'">Deklaracija o oznakah</xsl:when>
    </xsl:choose>
  </A>
</xsl:param>
<xsl:param name="LABEL-classDecl">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">classDecl</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">Class declaration</xsl:when>
      <xsl:when test="$lang = 'sl'">Deklaracija o razredih</xsl:when>
    </xsl:choose>
  </A>
</xsl:param>
<xsl:param name="LABEL-fsDecl">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">fsDecl</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">Feature-structure declaration</xsl:when>
      <xsl:when test="$lang = 'sl'">Deklaracija lastnostnih strukturah</xsl:when>
    </xsl:choose>
  </A>
</xsl:param>
<xsl:param name="LABEL-fsdDecl">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">fsdDecl</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">Feature-system declaration</xsl:when>
      <xsl:when test="$lang = 'sl'">Deklaracija sistema lastnostnih struktur</xsl:when>
    </xsl:choose>
  </A>
</xsl:param>
<xsl:param name="LABEL-flib">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">flib</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">Feature library</xsl:when>
      <xsl:when test="$lang = 'sl'">Knji&#x17E;nica lastnosti</xsl:when>
    </xsl:choose>
  </A>
  <xsl:choose>
    <xsl:when test="$lang = 'en'"> (values not shown)</xsl:when>
    <xsl:when test="$lang = 'sl'"> (vrednosti niso prikazane)</xsl:when>
  </xsl:choose>
</xsl:param>
<xsl:param name="LABEL-fslib">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">fslib</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">Feature-structure library</xsl:when>
      <xsl:when test="$lang = 'sl'">Knji&#x17E;nica lastnostnih struktur</xsl:when>
    </xsl:choose>
  </A>
  <xsl:choose>
    <xsl:when test="$lang = 'en'"> (values not shown)</xsl:when>
    <xsl:when test="$lang = 'sl'"> (vrednosti niso prikazane)</xsl:when>
  </xsl:choose>
</xsl:param>

<xsl:param name="LABEL-extent">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">extent</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">Extent</xsl:when>
      <xsl:when test="$lang = 'sl'">Obseg</xsl:when>
    </xsl:choose>
  </A>
</xsl:param>
<xsl:param name="LABEL-taxonomy">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">taxonomy</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">Taxonomy</xsl:when>
      <xsl:when test="$lang = 'sl'">Taksonomija</xsl:when>
    </xsl:choose>
  </A>
</xsl:param>
<xsl:param name="LABEL-category">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">category</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">Category</xsl:when>
      <xsl:when test="$lang = 'sl'">Kategorija</xsl:when>
    </xsl:choose>
  </A>
</xsl:param>
<xsl:param name="LABEL-correction">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">correction</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">Correction</xsl:when>
      <xsl:when test="$lang = 'sl'">Popravki</xsl:when>
    </xsl:choose>
  </A>
</xsl:param>
<xsl:param name="LABEL-hyphenation">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">hyphenation</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">Hyphenation</xsl:when>
      <xsl:when test="$lang = 'sl'">Deljaji</xsl:when>
    </xsl:choose>
  </A>
</xsl:param>
<xsl:param name="LABEL-normalization">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">normalization</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">Normalisation</xsl:when>
      <xsl:when test="$lang = 'sl'">Normalizacija</xsl:when>
    </xsl:choose>
  </A>
</xsl:param>
<xsl:param name="LABEL-quotation">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">quotation</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">Quotation</xsl:when>
      <xsl:when test="$lang = 'sl'">Navednice</xsl:when>
    </xsl:choose>
  </A>
</xsl:param>
<xsl:param name="LABEL-segmentation">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">segmentation</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">Segmentation</xsl:when>
      <xsl:when test="$lang = 'sl'">Segmentacija</xsl:when>
    </xsl:choose>
  </A>
</xsl:param>
<xsl:param name="LABEL-stdVals">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">stdVals</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">Standard values</xsl:when>
      <xsl:when test="$lang = 'sl'">Standardne vrednosti</xsl:when>
    </xsl:choose>
  </A>
</xsl:param>
<xsl:param name="LABEL-interpretation">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">interpretation</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">Interpretation</xsl:when>
      <xsl:when test="$lang = 'sl'">Interpretacija</xsl:when>
    </xsl:choose>
  </A>
</xsl:param>
<xsl:param name="LABEL-imprint">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">imprint</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">Imprint</xsl:when>
      <xsl:when test="$lang = 'sl'">Impresum</xsl:when>
    </xsl:choose>
  </A>
</xsl:param>
<xsl:param name="LABEL-pubPlace">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">pubPlace</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">Place of publication</xsl:when>
      <xsl:when test="$lang = 'sl'">Mesto publikacije</xsl:when>
    </xsl:choose>
  </A>
</xsl:param>
<xsl:param name="LABEL-langUsage">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">langUsage</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">Language use</xsl:when>
      <xsl:when test="$lang = 'sl'">Jeziki</xsl:when>
    </xsl:choose>
  </A>
</xsl:param>
<xsl:param name="LABEL-handList">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">handList</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">Hand list</xsl:when>
      <xsl:when test="$lang = 'sl'">Seznam rok</xsl:when>
    </xsl:choose>
  </A>
</xsl:param>
<xsl:param name="LABEL-bibl">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">bibl</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">Bibliographic item</xsl:when>
      <xsl:when test="$lang = 'sl'">Bibliografska enota</xsl:when>
    </xsl:choose>
  </A>
</xsl:param>
<xsl:param name="LABEL-listBibl">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">listBibl</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">Bibliography list</xsl:when>
      <xsl:when test="$lang = 'sl'">Seznam bibliografskih enot</xsl:when>
    </xsl:choose>
  </A>
</xsl:param>
<xsl:param name="LABEL-titleStmt-editor">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">editor</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">Editor</xsl:when>
      <xsl:when test="$lang = 'sl'">Urednik</xsl:when>
    </xsl:choose>
  </A>
</xsl:param>
<xsl:param name="LABEL-principal">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">principal</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">Principal researcher</xsl:when>
      <xsl:when test="$lang = 'sl'">Nosilec</xsl:when>
    </xsl:choose>
  </A>
</xsl:param>
<xsl:param name="LABEL-editor">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">editor</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">(ed.)</xsl:when>
      <xsl:when test="$lang = 'sl'">(ur.)</xsl:when>
    </xsl:choose>
  </A>
</xsl:param>
<xsl:param name="LABEL-edition">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">edition</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">Edition</xsl:when>
      <xsl:when test="$lang = 'sl'">Izdaja</xsl:when>
    </xsl:choose>
  </A>
</xsl:param>
<xsl:param name="LABEL-monogr">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">monogr</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">Monograph level</xsl:when>
      <xsl:when test="$lang = 'sl'">Monografska raven</xsl:when>
    </xsl:choose>
  </A>
</xsl:param>
<xsl:param name="LABEL-analytic">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">analytic</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">Analytic level</xsl:when>
      <xsl:when test="$lang = 'sl'">Ananaliti&#x10D;na raven</xsl:when>
    </xsl:choose>
  </A>
</xsl:param>
<xsl:param name="LABEL-note">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">note</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">Note</xsl:when>
      <xsl:when test="$lang = 'sl'">Opomba</xsl:when>
    </xsl:choose>
  </A>
</xsl:param>
<xsl:param name="LABEL-address">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">address</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">Address</xsl:when>
      <xsl:when test="$lang = 'sl'">Naslov</xsl:when>
    </xsl:choose>
  </A>
</xsl:param>
<xsl:param name="LABEL-availability">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">availability</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">Availiability</xsl:when>
      <xsl:when test="$lang = 'sl'">Dostopnost</xsl:when>
    </xsl:choose>
  </A>
</xsl:param>
<xsl:param name="LABEL-idno">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">idno</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">Identifier number</xsl:when>
      <xsl:when test="$lang = 'sl'">Identifikacijska &#353;tevilka</xsl:when>
    </xsl:choose>
  </A>
</xsl:param>
<xsl:param name="LABEL-distributor">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">distributor</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">Distributor</xsl:when>
      <xsl:when test="$lang = 'sl'">Distributer</xsl:when>
    </xsl:choose>
  </A>
</xsl:param>
<xsl:param name="LABEL-publisher">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">publisher</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">Publisher</xsl:when>
      <xsl:when test="$lang = 'sl'">Izdajatelj</xsl:when>
    </xsl:choose>
  </A>
</xsl:param>
<xsl:param name="LABEL-title">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">title</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">Title</xsl:when>
      <xsl:when test="$lang = 'sl'">Naslov</xsl:when>
    </xsl:choose>
  </A>
</xsl:param>
<xsl:param name="LABEL-author">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">author</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">Author</xsl:when>
      <xsl:when test="$lang = 'sl'">Avtor</xsl:when>
    </xsl:choose>
  </A>
</xsl:param>
<xsl:param name="LABEL-date">
  <A>
    <xsl:attribute name="href">
      <xsl:call-template name="teip4-elts">
        <xsl:with-param name="gi">date</xsl:with-param>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="$lang = 'en'">Date</xsl:when>
      <xsl:when test="$lang = 'sl'">Datum</xsl:when>
    </xsl:choose>
  </A>
</xsl:param>
</xsl:stylesheet>
